#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['bowtie',
 'bowtie.feedback',
 'bowtie.src.node_modules.node-gyp.gyp.pylib.gyp',
 'bowtie.src.node_modules.node-gyp.gyp.pylib.gyp.generator',
 'bowtie.tests']

package_data = \
{'': ['*'],
 'bowtie': ['.pyre/*',
            '.pyre/server/*',
            '.pyre/watchman/*',
            'src/*',
            'src/node_modules/*',
            'src/node_modules/.bin/*',
            'src/node_modules/@ant-design/*',
            'src/node_modules/@ant-design/icons-react/*',
            'src/node_modules/@ant-design/icons-react/es/*',
            'src/node_modules/@ant-design/icons-react/es/components/*',
            'src/node_modules/@ant-design/icons-react/lib/*',
            'src/node_modules/@ant-design/icons-react/lib/components/*',
            'src/node_modules/@ant-design/icons/*',
            'src/node_modules/@ant-design/icons/inline-svg/*',
            'src/node_modules/@ant-design/icons/inline-svg/fill/*',
            'src/node_modules/@ant-design/icons/inline-svg/outline/*',
            'src/node_modules/@ant-design/icons/inline-svg/twotone/*',
            'src/node_modules/@ant-design/icons/lib/*',
            'src/node_modules/@ant-design/icons/lib/fill/*',
            'src/node_modules/@ant-design/icons/lib/outline/*',
            'src/node_modules/@ant-design/icons/lib/twotone/*',
            'src/node_modules/@ant-design/icons/svg/*',
            'src/node_modules/@ant-design/icons/svg/fill/*',
            'src/node_modules/@ant-design/icons/svg/outline/*',
            'src/node_modules/@ant-design/icons/svg/twotone/*',
            'src/node_modules/@babel/*',
            'src/node_modules/@babel/code-frame/*',
            'src/node_modules/@babel/code-frame/lib/*',
            'src/node_modules/@babel/core/*',
            'src/node_modules/@babel/core/lib/*',
            'src/node_modules/@babel/core/lib/config/*',
            'src/node_modules/@babel/core/lib/config/files/*',
            'src/node_modules/@babel/core/lib/config/helpers/*',
            'src/node_modules/@babel/core/lib/config/validation/*',
            'src/node_modules/@babel/core/lib/tools/*',
            'src/node_modules/@babel/core/lib/transformation/*',
            'src/node_modules/@babel/core/lib/transformation/file/*',
            'src/node_modules/@babel/core/lib/transformation/util/*',
            'src/node_modules/@babel/core/node_modules/*',
            'src/node_modules/@babel/core/node_modules/.bin/*',
            'src/node_modules/@babel/core/node_modules/@babel/*',
            'src/node_modules/@babel/core/node_modules/@babel/parser/*',
            'src/node_modules/@babel/core/node_modules/@babel/parser/bin/*',
            'src/node_modules/@babel/core/node_modules/@babel/parser/lib/*',
            'src/node_modules/@babel/core/node_modules/@babel/parser/typings/*',
            'src/node_modules/@babel/core/node_modules/@babel/template/*',
            'src/node_modules/@babel/core/node_modules/@babel/template/lib/*',
            'src/node_modules/@babel/core/node_modules/@babel/template/node_modules/*',
            'src/node_modules/@babel/core/node_modules/@babel/template/node_modules/.bin/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/asserts/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/asserts/generated/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/builders/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/builders/flow/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/builders/generated/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/builders/react/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/clone/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/comments/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/constants/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/constants/generated/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/converters/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/definitions/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/modifications/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/modifications/flow/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/retrievers/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/traverse/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/utils/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/utils/react/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/validators/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/validators/generated/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/lib/validators/react/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/scripts/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/scripts/generators/*',
            'src/node_modules/@babel/core/node_modules/@babel/types/scripts/utils/*',
            'src/node_modules/@babel/core/node_modules/semver/*',
            'src/node_modules/@babel/core/node_modules/semver/bin/*',
            'src/node_modules/@babel/core/node_modules/source-map/*',
            'src/node_modules/@babel/core/node_modules/source-map/dist/*',
            'src/node_modules/@babel/core/node_modules/source-map/lib/*',
            'src/node_modules/@babel/generator/*',
            'src/node_modules/@babel/generator/lib/*',
            'src/node_modules/@babel/generator/lib/generators/*',
            'src/node_modules/@babel/generator/lib/node/*',
            'src/node_modules/@babel/generator/node_modules/*',
            'src/node_modules/@babel/generator/node_modules/.bin/*',
            'src/node_modules/@babel/generator/node_modules/@babel/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/asserts/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/asserts/generated/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/builders/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/builders/flow/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/builders/generated/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/builders/react/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/clone/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/comments/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/constants/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/constants/generated/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/converters/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/definitions/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/modifications/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/modifications/flow/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/retrievers/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/traverse/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/utils/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/utils/react/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/validators/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/validators/generated/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/lib/validators/react/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/scripts/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/scripts/generators/*',
            'src/node_modules/@babel/generator/node_modules/@babel/types/scripts/utils/*',
            'src/node_modules/@babel/generator/node_modules/jsesc/*',
            'src/node_modules/@babel/generator/node_modules/jsesc/bin/*',
            'src/node_modules/@babel/generator/node_modules/jsesc/man/*',
            'src/node_modules/@babel/generator/node_modules/source-map/*',
            'src/node_modules/@babel/generator/node_modules/source-map/dist/*',
            'src/node_modules/@babel/generator/node_modules/source-map/lib/*',
            'src/node_modules/@babel/helper-annotate-as-pure/*',
            'src/node_modules/@babel/helper-annotate-as-pure/lib/*',
            'src/node_modules/@babel/helper-builder-binary-assignment-operator-visitor/*',
            'src/node_modules/@babel/helper-builder-binary-assignment-operator-visitor/lib/*',
            'src/node_modules/@babel/helper-builder-react-jsx/*',
            'src/node_modules/@babel/helper-builder-react-jsx/lib/*',
            'src/node_modules/@babel/helper-call-delegate/*',
            'src/node_modules/@babel/helper-call-delegate/lib/*',
            'src/node_modules/@babel/helper-define-map/*',
            'src/node_modules/@babel/helper-define-map/lib/*',
            'src/node_modules/@babel/helper-explode-assignable-expression/*',
            'src/node_modules/@babel/helper-explode-assignable-expression/lib/*',
            'src/node_modules/@babel/helper-function-name/*',
            'src/node_modules/@babel/helper-function-name/lib/*',
            'src/node_modules/@babel/helper-get-function-arity/*',
            'src/node_modules/@babel/helper-get-function-arity/lib/*',
            'src/node_modules/@babel/helper-hoist-variables/*',
            'src/node_modules/@babel/helper-hoist-variables/lib/*',
            'src/node_modules/@babel/helper-member-expression-to-functions/*',
            'src/node_modules/@babel/helper-member-expression-to-functions/lib/*',
            'src/node_modules/@babel/helper-module-imports/*',
            'src/node_modules/@babel/helper-module-imports/lib/*',
            'src/node_modules/@babel/helper-module-transforms/*',
            'src/node_modules/@babel/helper-module-transforms/lib/*',
            'src/node_modules/@babel/helper-optimise-call-expression/*',
            'src/node_modules/@babel/helper-optimise-call-expression/lib/*',
            'src/node_modules/@babel/helper-plugin-utils/*',
            'src/node_modules/@babel/helper-plugin-utils/lib/*',
            'src/node_modules/@babel/helper-plugin-utils/src/*',
            'src/node_modules/@babel/helper-regex/*',
            'src/node_modules/@babel/helper-regex/lib/*',
            'src/node_modules/@babel/helper-remap-async-to-generator/*',
            'src/node_modules/@babel/helper-remap-async-to-generator/lib/*',
            'src/node_modules/@babel/helper-replace-supers/*',
            'src/node_modules/@babel/helper-replace-supers/lib/*',
            'src/node_modules/@babel/helper-simple-access/*',
            'src/node_modules/@babel/helper-simple-access/lib/*',
            'src/node_modules/@babel/helper-split-export-declaration/*',
            'src/node_modules/@babel/helper-split-export-declaration/lib/*',
            'src/node_modules/@babel/helper-wrap-function/*',
            'src/node_modules/@babel/helper-wrap-function/lib/*',
            'src/node_modules/@babel/helpers/*',
            'src/node_modules/@babel/helpers/lib/*',
            'src/node_modules/@babel/helpers/node_modules/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/parser/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/parser/bin/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/parser/lib/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/parser/typings/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/template/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/template/lib/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/template/node_modules/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/template/node_modules/.bin/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/asserts/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/asserts/generated/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/builders/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/builders/flow/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/builders/generated/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/builders/react/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/clone/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/comments/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/constants/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/constants/generated/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/converters/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/definitions/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/modifications/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/modifications/flow/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/retrievers/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/traverse/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/utils/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/utils/react/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/validators/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/validators/generated/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/lib/validators/react/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/scripts/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/scripts/generators/*',
            'src/node_modules/@babel/helpers/node_modules/@babel/types/scripts/utils/*',
            'src/node_modules/@babel/highlight/*',
            'src/node_modules/@babel/highlight/lib/*',
            'src/node_modules/@babel/highlight/node_modules/*',
            'src/node_modules/@babel/highlight/node_modules/js-tokens/*',
            'src/node_modules/@babel/parser/*',
            'src/node_modules/@babel/parser/bin/*',
            'src/node_modules/@babel/parser/lib/*',
            'src/node_modules/@babel/parser/typings/*',
            'src/node_modules/@babel/plugin-proposal-async-generator-functions/*',
            'src/node_modules/@babel/plugin-proposal-async-generator-functions/lib/*',
            'src/node_modules/@babel/plugin-proposal-class-properties/*',
            'src/node_modules/@babel/plugin-proposal-class-properties/lib/*',
            'src/node_modules/@babel/plugin-proposal-json-strings/*',
            'src/node_modules/@babel/plugin-proposal-json-strings/lib/*',
            'src/node_modules/@babel/plugin-proposal-object-rest-spread/*',
            'src/node_modules/@babel/plugin-proposal-object-rest-spread/lib/*',
            'src/node_modules/@babel/plugin-proposal-optional-catch-binding/*',
            'src/node_modules/@babel/plugin-proposal-optional-catch-binding/lib/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/lib/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/src/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/with-unicode-flag/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/with-unicode-flag/script-extensions/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/with-unicode-flag/simple/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/with-unicode-flag/unicode-10/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/with-unicode-flag/unicode-11/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/without-unicode-flag/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/without-unicode-flag/script-extensions/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/without-unicode-flag/simple/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/without-unicode-flag/unicode-10/*',
            'src/node_modules/@babel/plugin-proposal-unicode-property-regex/test/fixtures/without-unicode-flag/unicode-11/*',
            'src/node_modules/@babel/plugin-syntax-async-generators/*',
            'src/node_modules/@babel/plugin-syntax-async-generators/lib/*',
            'src/node_modules/@babel/plugin-syntax-class-properties/*',
            'src/node_modules/@babel/plugin-syntax-class-properties/lib/*',
            'src/node_modules/@babel/plugin-syntax-json-strings/*',
            'src/node_modules/@babel/plugin-syntax-json-strings/lib/*',
            'src/node_modules/@babel/plugin-syntax-jsx/*',
            'src/node_modules/@babel/plugin-syntax-jsx/lib/*',
            'src/node_modules/@babel/plugin-syntax-object-rest-spread/*',
            'src/node_modules/@babel/plugin-syntax-object-rest-spread/lib/*',
            'src/node_modules/@babel/plugin-syntax-optional-catch-binding/*',
            'src/node_modules/@babel/plugin-syntax-optional-catch-binding/lib/*',
            'src/node_modules/@babel/plugin-transform-arrow-functions/*',
            'src/node_modules/@babel/plugin-transform-arrow-functions/lib/*',
            'src/node_modules/@babel/plugin-transform-async-to-generator/*',
            'src/node_modules/@babel/plugin-transform-async-to-generator/lib/*',
            'src/node_modules/@babel/plugin-transform-block-scoped-functions/*',
            'src/node_modules/@babel/plugin-transform-block-scoped-functions/lib/*',
            'src/node_modules/@babel/plugin-transform-block-scoping/*',
            'src/node_modules/@babel/plugin-transform-block-scoping/lib/*',
            'src/node_modules/@babel/plugin-transform-classes/*',
            'src/node_modules/@babel/plugin-transform-classes/lib/*',
            'src/node_modules/@babel/plugin-transform-computed-properties/*',
            'src/node_modules/@babel/plugin-transform-computed-properties/lib/*',
            'src/node_modules/@babel/plugin-transform-destructuring/*',
            'src/node_modules/@babel/plugin-transform-destructuring/lib/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/lib/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/src/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/test/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/test/fixtures/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/test/fixtures/dotall-regex/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/test/fixtures/dotall-regex/simple/*',
            'src/node_modules/@babel/plugin-transform-dotall-regex/test/fixtures/dotall-regex/with-unicode-flag/*',
            'src/node_modules/@babel/plugin-transform-duplicate-keys/*',
            'src/node_modules/@babel/plugin-transform-duplicate-keys/lib/*',
            'src/node_modules/@babel/plugin-transform-exponentiation-operator/*',
            'src/node_modules/@babel/plugin-transform-exponentiation-operator/lib/*',
            'src/node_modules/@babel/plugin-transform-for-of/*',
            'src/node_modules/@babel/plugin-transform-for-of/lib/*',
            'src/node_modules/@babel/plugin-transform-function-name/*',
            'src/node_modules/@babel/plugin-transform-function-name/lib/*',
            'src/node_modules/@babel/plugin-transform-literals/*',
            'src/node_modules/@babel/plugin-transform-literals/lib/*',
            'src/node_modules/@babel/plugin-transform-modules-amd/*',
            'src/node_modules/@babel/plugin-transform-modules-amd/lib/*',
            'src/node_modules/@babel/plugin-transform-modules-commonjs/*',
            'src/node_modules/@babel/plugin-transform-modules-commonjs/lib/*',
            'src/node_modules/@babel/plugin-transform-modules-systemjs/*',
            'src/node_modules/@babel/plugin-transform-modules-systemjs/lib/*',
            'src/node_modules/@babel/plugin-transform-modules-umd/*',
            'src/node_modules/@babel/plugin-transform-modules-umd/lib/*',
            'src/node_modules/@babel/plugin-transform-new-target/*',
            'src/node_modules/@babel/plugin-transform-new-target/lib/*',
            'src/node_modules/@babel/plugin-transform-object-super/*',
            'src/node_modules/@babel/plugin-transform-object-super/lib/*',
            'src/node_modules/@babel/plugin-transform-parameters/*',
            'src/node_modules/@babel/plugin-transform-parameters/lib/*',
            'src/node_modules/@babel/plugin-transform-react-display-name/*',
            'src/node_modules/@babel/plugin-transform-react-display-name/lib/*',
            'src/node_modules/@babel/plugin-transform-react-jsx-self/*',
            'src/node_modules/@babel/plugin-transform-react-jsx-self/lib/*',
            'src/node_modules/@babel/plugin-transform-react-jsx-source/*',
            'src/node_modules/@babel/plugin-transform-react-jsx-source/lib/*',
            'src/node_modules/@babel/plugin-transform-react-jsx/*',
            'src/node_modules/@babel/plugin-transform-react-jsx/lib/*',
            'src/node_modules/@babel/plugin-transform-regenerator/*',
            'src/node_modules/@babel/plugin-transform-regenerator/lib/*',
            'src/node_modules/@babel/plugin-transform-shorthand-properties/*',
            'src/node_modules/@babel/plugin-transform-shorthand-properties/lib/*',
            'src/node_modules/@babel/plugin-transform-spread/*',
            'src/node_modules/@babel/plugin-transform-spread/lib/*',
            'src/node_modules/@babel/plugin-transform-sticky-regex/*',
            'src/node_modules/@babel/plugin-transform-sticky-regex/lib/*',
            'src/node_modules/@babel/plugin-transform-template-literals/*',
            'src/node_modules/@babel/plugin-transform-template-literals/lib/*',
            'src/node_modules/@babel/plugin-transform-typeof-symbol/*',
            'src/node_modules/@babel/plugin-transform-typeof-symbol/lib/*',
            'src/node_modules/@babel/plugin-transform-unicode-regex/*',
            'src/node_modules/@babel/plugin-transform-unicode-regex/lib/*',
            'src/node_modules/@babel/polyfill/*',
            'src/node_modules/@babel/polyfill/dist/*',
            'src/node_modules/@babel/polyfill/lib/*',
            'src/node_modules/@babel/polyfill/scripts/*',
            'src/node_modules/@babel/preset-env/*',
            'src/node_modules/@babel/preset-env/data/*',
            'src/node_modules/@babel/preset-env/lib/*',
            'src/node_modules/@babel/preset-env/node_modules/*',
            'src/node_modules/@babel/preset-env/node_modules/.bin/*',
            'src/node_modules/@babel/preset-react/*',
            'src/node_modules/@babel/preset-react/lib/*',
            'src/node_modules/@babel/runtime/*',
            'src/node_modules/@babel/runtime/helpers/*',
            'src/node_modules/@babel/runtime/helpers/esm/*',
            'src/node_modules/@babel/runtime/node_modules/*',
            'src/node_modules/@babel/runtime/node_modules/regenerator-runtime/*',
            'src/node_modules/@babel/runtime/regenerator/*',
            'src/node_modules/@babel/template/*',
            'src/node_modules/@babel/template/lib/*',
            'src/node_modules/@babel/template/node_modules/*',
            'src/node_modules/@babel/template/node_modules/.bin/*',
            'src/node_modules/@babel/traverse/*',
            'src/node_modules/@babel/traverse/lib/*',
            'src/node_modules/@babel/traverse/lib/path/*',
            'src/node_modules/@babel/traverse/lib/path/inference/*',
            'src/node_modules/@babel/traverse/lib/path/lib/*',
            'src/node_modules/@babel/traverse/lib/scope/*',
            'src/node_modules/@babel/traverse/lib/scope/lib/*',
            'src/node_modules/@babel/traverse/node_modules/*',
            'src/node_modules/@babel/traverse/node_modules/.bin/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/generator/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/generator/lib/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/generator/lib/generators/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/generator/lib/node/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/generator/node_modules/*',
            'src/node_modules/@babel/traverse/node_modules/@babel/generator/node_modules/.bin/*',
            'src/node_modules/@babel/traverse/node_modules/jsesc/*',
            'src/node_modules/@babel/traverse/node_modules/jsesc/bin/*',
            'src/node_modules/@babel/traverse/node_modules/jsesc/man/*',
            'src/node_modules/@babel/traverse/node_modules/source-map/*',
            'src/node_modules/@babel/traverse/node_modules/source-map/dist/*',
            'src/node_modules/@babel/traverse/node_modules/source-map/lib/*',
            'src/node_modules/@babel/types/*',
            'src/node_modules/@babel/types/lib/*',
            'src/node_modules/@babel/types/lib/asserts/*',
            'src/node_modules/@babel/types/lib/asserts/generated/*',
            'src/node_modules/@babel/types/lib/builders/*',
            'src/node_modules/@babel/types/lib/builders/flow/*',
            'src/node_modules/@babel/types/lib/builders/generated/*',
            'src/node_modules/@babel/types/lib/builders/react/*',
            'src/node_modules/@babel/types/lib/clone/*',
            'src/node_modules/@babel/types/lib/comments/*',
            'src/node_modules/@babel/types/lib/constants/*',
            'src/node_modules/@babel/types/lib/constants/generated/*',
            'src/node_modules/@babel/types/lib/converters/*',
            'src/node_modules/@babel/types/lib/definitions/*',
            'src/node_modules/@babel/types/lib/modifications/*',
            'src/node_modules/@babel/types/lib/modifications/flow/*',
            'src/node_modules/@babel/types/lib/retrievers/*',
            'src/node_modules/@babel/types/lib/traverse/*',
            'src/node_modules/@babel/types/lib/utils/*',
            'src/node_modules/@babel/types/lib/utils/react/*',
            'src/node_modules/@babel/types/lib/validators/*',
            'src/node_modules/@babel/types/lib/validators/generated/*',
            'src/node_modules/@babel/types/lib/validators/react/*',
            'src/node_modules/@babel/types/scripts/*',
            'src/node_modules/@babel/types/scripts/generators/*',
            'src/node_modules/@babel/types/scripts/utils/*',
            'src/node_modules/@webassemblyjs/*',
            'src/node_modules/@webassemblyjs/ast/*',
            'src/node_modules/@webassemblyjs/ast/esm/*',
            'src/node_modules/@webassemblyjs/ast/esm/transform/*',
            'src/node_modules/@webassemblyjs/ast/esm/transform/denormalize-type-references/*',
            'src/node_modules/@webassemblyjs/ast/esm/transform/wast-identifier-to-index/*',
            'src/node_modules/@webassemblyjs/ast/esm/types/*',
            'src/node_modules/@webassemblyjs/ast/lib/*',
            'src/node_modules/@webassemblyjs/ast/lib/transform/*',
            'src/node_modules/@webassemblyjs/ast/lib/transform/denormalize-type-references/*',
            'src/node_modules/@webassemblyjs/ast/lib/transform/wast-identifier-to-index/*',
            'src/node_modules/@webassemblyjs/ast/lib/types/*',
            'src/node_modules/@webassemblyjs/ast/scripts/*',
            'src/node_modules/@webassemblyjs/floating-point-hex-parser/*',
            'src/node_modules/@webassemblyjs/floating-point-hex-parser/esm/*',
            'src/node_modules/@webassemblyjs/floating-point-hex-parser/lib/*',
            'src/node_modules/@webassemblyjs/helper-api-error/*',
            'src/node_modules/@webassemblyjs/helper-api-error/esm/*',
            'src/node_modules/@webassemblyjs/helper-api-error/lib/*',
            'src/node_modules/@webassemblyjs/helper-buffer/*',
            'src/node_modules/@webassemblyjs/helper-buffer/esm/*',
            'src/node_modules/@webassemblyjs/helper-buffer/lib/*',
            'src/node_modules/@webassemblyjs/helper-code-frame/*',
            'src/node_modules/@webassemblyjs/helper-code-frame/esm/*',
            'src/node_modules/@webassemblyjs/helper-code-frame/lib/*',
            'src/node_modules/@webassemblyjs/helper-fsm/*',
            'src/node_modules/@webassemblyjs/helper-fsm/esm/*',
            'src/node_modules/@webassemblyjs/helper-fsm/lib/*',
            'src/node_modules/@webassemblyjs/helper-module-context/*',
            'src/node_modules/@webassemblyjs/helper-module-context/esm/*',
            'src/node_modules/@webassemblyjs/helper-module-context/lib/*',
            'src/node_modules/@webassemblyjs/helper-module-context/src/*',
            'src/node_modules/@webassemblyjs/helper-module-context/test/*',
            'src/node_modules/@webassemblyjs/helper-wasm-bytecode/*',
            'src/node_modules/@webassemblyjs/helper-wasm-bytecode/esm/*',
            'src/node_modules/@webassemblyjs/helper-wasm-bytecode/lib/*',
            'src/node_modules/@webassemblyjs/helper-wasm-section/*',
            'src/node_modules/@webassemblyjs/helper-wasm-section/esm/*',
            'src/node_modules/@webassemblyjs/helper-wasm-section/lib/*',
            'src/node_modules/@webassemblyjs/ieee754/*',
            'src/node_modules/@webassemblyjs/ieee754/esm/*',
            'src/node_modules/@webassemblyjs/ieee754/lib/*',
            'src/node_modules/@webassemblyjs/ieee754/src/*',
            'src/node_modules/@webassemblyjs/leb128/*',
            'src/node_modules/@webassemblyjs/leb128/esm/*',
            'src/node_modules/@webassemblyjs/leb128/lib/*',
            'src/node_modules/@webassemblyjs/utf8/*',
            'src/node_modules/@webassemblyjs/utf8/esm/*',
            'src/node_modules/@webassemblyjs/utf8/lib/*',
            'src/node_modules/@webassemblyjs/utf8/src/*',
            'src/node_modules/@webassemblyjs/utf8/test/*',
            'src/node_modules/@webassemblyjs/wasm-edit/*',
            'src/node_modules/@webassemblyjs/wasm-edit/esm/*',
            'src/node_modules/@webassemblyjs/wasm-edit/lib/*',
            'src/node_modules/@webassemblyjs/wasm-gen/*',
            'src/node_modules/@webassemblyjs/wasm-gen/esm/*',
            'src/node_modules/@webassemblyjs/wasm-gen/esm/encoder/*',
            'src/node_modules/@webassemblyjs/wasm-gen/lib/*',
            'src/node_modules/@webassemblyjs/wasm-gen/lib/encoder/*',
            'src/node_modules/@webassemblyjs/wasm-opt/*',
            'src/node_modules/@webassemblyjs/wasm-opt/esm/*',
            'src/node_modules/@webassemblyjs/wasm-opt/lib/*',
            'src/node_modules/@webassemblyjs/wasm-parser/*',
            'src/node_modules/@webassemblyjs/wasm-parser/esm/*',
            'src/node_modules/@webassemblyjs/wasm-parser/esm/types/*',
            'src/node_modules/@webassemblyjs/wasm-parser/lib/*',
            'src/node_modules/@webassemblyjs/wasm-parser/lib/types/*',
            'src/node_modules/@webassemblyjs/wast-parser/*',
            'src/node_modules/@webassemblyjs/wast-parser/esm/*',
            'src/node_modules/@webassemblyjs/wast-parser/lib/*',
            'src/node_modules/@webassemblyjs/wast-printer/*',
            'src/node_modules/@webassemblyjs/wast-printer/esm/*',
            'src/node_modules/@webassemblyjs/wast-printer/lib/*',
            'src/node_modules/@xtuc/*',
            'src/node_modules/@xtuc/ieee754/*',
            'src/node_modules/@xtuc/ieee754/dist/*',
            'src/node_modules/@xtuc/long/*',
            'src/node_modules/@xtuc/long/dist/*',
            'src/node_modules/@xtuc/long/src/*',
            'src/node_modules/abbrev/*',
            'src/node_modules/acorn-dynamic-import/*',
            'src/node_modules/acorn-dynamic-import/lib/*',
            'src/node_modules/acorn-dynamic-import/node_modules/*',
            'src/node_modules/acorn-dynamic-import/node_modules/.bin/*',
            'src/node_modules/acorn-dynamic-import/node_modules/acorn/*',
            'src/node_modules/acorn-dynamic-import/node_modules/acorn/bin/*',
            'src/node_modules/acorn-dynamic-import/node_modules/acorn/dist/*',
            'src/node_modules/acorn-dynamic-import/src/*',
            'src/node_modules/acorn/*',
            'src/node_modules/acorn/bin/*',
            'src/node_modules/acorn/dist/*',
            'src/node_modules/add-dom-event-listener/*',
            'src/node_modules/add-dom-event-listener/lib/*',
            'src/node_modules/after/*',
            'src/node_modules/after/test/*',
            'src/node_modules/ajv-errors/*',
            'src/node_modules/ajv-errors/lib/*',
            'src/node_modules/ajv-errors/lib/dot/*',
            'src/node_modules/ajv-errors/lib/dotjs/*',
            'src/node_modules/ajv-keywords/*',
            'src/node_modules/ajv-keywords/keywords/*',
            'src/node_modules/ajv-keywords/keywords/dot/*',
            'src/node_modules/ajv-keywords/keywords/dotjs/*',
            'src/node_modules/ajv/*',
            'src/node_modules/ajv/dist/*',
            'src/node_modules/ajv/lib/*',
            'src/node_modules/ajv/lib/compile/*',
            'src/node_modules/ajv/lib/dot/*',
            'src/node_modules/ajv/lib/dotjs/*',
            'src/node_modules/ajv/lib/refs/*',
            'src/node_modules/ajv/scripts/*',
            'src/node_modules/amdefine/*',
            'src/node_modules/ansi-regex/*',
            'src/node_modules/ansi-styles/*',
            'src/node_modules/ant-design-palettes/*',
            'src/node_modules/ant-design-palettes/lib/*',
            'src/node_modules/ant-design-palettes/src/*',
            'src/node_modules/antd/*',
            'src/node_modules/antd/dist/*',
            'src/node_modules/antd/es/*',
            'src/node_modules/antd/es/_util/*',
            'src/node_modules/antd/es/affix/*',
            'src/node_modules/antd/es/affix/style/*',
            'src/node_modules/antd/es/alert/*',
            'src/node_modules/antd/es/alert/style/*',
            'src/node_modules/antd/es/anchor/*',
            'src/node_modules/antd/es/anchor/style/*',
            'src/node_modules/antd/es/auto-complete/*',
            'src/node_modules/antd/es/auto-complete/style/*',
            'src/node_modules/antd/es/avatar/*',
            'src/node_modules/antd/es/avatar/style/*',
            'src/node_modules/antd/es/back-top/*',
            'src/node_modules/antd/es/back-top/style/*',
            'src/node_modules/antd/es/badge/*',
            'src/node_modules/antd/es/badge/style/*',
            'src/node_modules/antd/es/breadcrumb/*',
            'src/node_modules/antd/es/breadcrumb/style/*',
            'src/node_modules/antd/es/button/*',
            'src/node_modules/antd/es/button/style/*',
            'src/node_modules/antd/es/calendar/*',
            'src/node_modules/antd/es/calendar/locale/*',
            'src/node_modules/antd/es/calendar/style/*',
            'src/node_modules/antd/es/card/*',
            'src/node_modules/antd/es/card/style/*',
            'src/node_modules/antd/es/carousel/*',
            'src/node_modules/antd/es/carousel/style/*',
            'src/node_modules/antd/es/cascader/*',
            'src/node_modules/antd/es/cascader/style/*',
            'src/node_modules/antd/es/checkbox/*',
            'src/node_modules/antd/es/checkbox/style/*',
            'src/node_modules/antd/es/col/*',
            'src/node_modules/antd/es/col/style/*',
            'src/node_modules/antd/es/collapse/*',
            'src/node_modules/antd/es/collapse/style/*',
            'src/node_modules/antd/es/date-picker/*',
            'src/node_modules/antd/es/date-picker/locale/*',
            'src/node_modules/antd/es/date-picker/style/*',
            'src/node_modules/antd/es/divider/*',
            'src/node_modules/antd/es/divider/style/*',
            'src/node_modules/antd/es/drawer/*',
            'src/node_modules/antd/es/drawer/style/*',
            'src/node_modules/antd/es/dropdown/*',
            'src/node_modules/antd/es/dropdown/style/*',
            'src/node_modules/antd/es/form/*',
            'src/node_modules/antd/es/form/__tests__/*',
            'src/node_modules/antd/es/form/style/*',
            'src/node_modules/antd/es/grid/*',
            'src/node_modules/antd/es/grid/style/*',
            'src/node_modules/antd/es/icon/*',
            'src/node_modules/antd/es/icon/style/*',
            'src/node_modules/antd/es/input-number/*',
            'src/node_modules/antd/es/input-number/style/*',
            'src/node_modules/antd/es/input/*',
            'src/node_modules/antd/es/input/style/*',
            'src/node_modules/antd/es/layout/*',
            'src/node_modules/antd/es/layout/style/*',
            'src/node_modules/antd/es/list/*',
            'src/node_modules/antd/es/list/style/*',
            'src/node_modules/antd/es/locale-provider/*',
            'src/node_modules/antd/es/locale-provider/style/*',
            'src/node_modules/antd/es/mention/*',
            'src/node_modules/antd/es/mention/style/*',
            'src/node_modules/antd/es/menu/*',
            'src/node_modules/antd/es/menu/style/*',
            'src/node_modules/antd/es/message/*',
            'src/node_modules/antd/es/message/style/*',
            'src/node_modules/antd/es/modal/*',
            'src/node_modules/antd/es/modal/style/*',
            'src/node_modules/antd/es/notification/*',
            'src/node_modules/antd/es/notification/style/*',
            'src/node_modules/antd/es/pagination/*',
            'src/node_modules/antd/es/pagination/style/*',
            'src/node_modules/antd/es/popconfirm/*',
            'src/node_modules/antd/es/popconfirm/style/*',
            'src/node_modules/antd/es/popover/*',
            'src/node_modules/antd/es/popover/style/*',
            'src/node_modules/antd/es/progress/*',
            'src/node_modules/antd/es/progress/style/*',
            'src/node_modules/antd/es/radio/*',
            'src/node_modules/antd/es/radio/style/*',
            'src/node_modules/antd/es/rate/*',
            'src/node_modules/antd/es/rate/style/*',
            'src/node_modules/antd/es/row/*',
            'src/node_modules/antd/es/row/style/*',
            'src/node_modules/antd/es/select/*',
            'src/node_modules/antd/es/select/style/*',
            'src/node_modules/antd/es/skeleton/*',
            'src/node_modules/antd/es/skeleton/style/*',
            'src/node_modules/antd/es/slider/*',
            'src/node_modules/antd/es/slider/style/*',
            'src/node_modules/antd/es/spin/*',
            'src/node_modules/antd/es/spin/style/*',
            'src/node_modules/antd/es/steps/*',
            'src/node_modules/antd/es/steps/style/*',
            'src/node_modules/antd/es/style/*',
            'src/node_modules/antd/es/style/color/*',
            'src/node_modules/antd/es/style/core/*',
            'src/node_modules/antd/es/style/core/motion/*',
            'src/node_modules/antd/es/style/mixins/*',
            'src/node_modules/antd/es/style/themes/*',
            'src/node_modules/antd/es/switch/*',
            'src/node_modules/antd/es/switch/style/*',
            'src/node_modules/antd/es/table/*',
            'src/node_modules/antd/es/table/style/*',
            'src/node_modules/antd/es/tabs/*',
            'src/node_modules/antd/es/tabs/style/*',
            'src/node_modules/antd/es/tag/*',
            'src/node_modules/antd/es/tag/style/*',
            'src/node_modules/antd/es/time-picker/*',
            'src/node_modules/antd/es/time-picker/locale/*',
            'src/node_modules/antd/es/time-picker/style/*',
            'src/node_modules/antd/es/timeline/*',
            'src/node_modules/antd/es/timeline/style/*',
            'src/node_modules/antd/es/tooltip/*',
            'src/node_modules/antd/es/tooltip/style/*',
            'src/node_modules/antd/es/transfer/*',
            'src/node_modules/antd/es/transfer/style/*',
            'src/node_modules/antd/es/tree-select/*',
            'src/node_modules/antd/es/tree-select/style/*',
            'src/node_modules/antd/es/tree/*',
            'src/node_modules/antd/es/tree/style/*',
            'src/node_modules/antd/es/upload/*',
            'src/node_modules/antd/es/upload/style/*',
            'src/node_modules/antd/es/version/*',
            'src/node_modules/antd/es/version/style/*',
            'src/node_modules/antd/lib/*',
            'src/node_modules/antd/lib/_util/*',
            'src/node_modules/antd/lib/affix/*',
            'src/node_modules/antd/lib/affix/style/*',
            'src/node_modules/antd/lib/alert/*',
            'src/node_modules/antd/lib/alert/style/*',
            'src/node_modules/antd/lib/anchor/*',
            'src/node_modules/antd/lib/anchor/style/*',
            'src/node_modules/antd/lib/auto-complete/*',
            'src/node_modules/antd/lib/auto-complete/style/*',
            'src/node_modules/antd/lib/avatar/*',
            'src/node_modules/antd/lib/avatar/style/*',
            'src/node_modules/antd/lib/back-top/*',
            'src/node_modules/antd/lib/back-top/style/*',
            'src/node_modules/antd/lib/badge/*',
            'src/node_modules/antd/lib/badge/style/*',
            'src/node_modules/antd/lib/breadcrumb/*',
            'src/node_modules/antd/lib/breadcrumb/style/*',
            'src/node_modules/antd/lib/button/*',
            'src/node_modules/antd/lib/button/style/*',
            'src/node_modules/antd/lib/calendar/*',
            'src/node_modules/antd/lib/calendar/locale/*',
            'src/node_modules/antd/lib/calendar/style/*',
            'src/node_modules/antd/lib/card/*',
            'src/node_modules/antd/lib/card/style/*',
            'src/node_modules/antd/lib/carousel/*',
            'src/node_modules/antd/lib/carousel/style/*',
            'src/node_modules/antd/lib/cascader/*',
            'src/node_modules/antd/lib/cascader/style/*',
            'src/node_modules/antd/lib/checkbox/*',
            'src/node_modules/antd/lib/checkbox/style/*',
            'src/node_modules/antd/lib/col/*',
            'src/node_modules/antd/lib/col/style/*',
            'src/node_modules/antd/lib/collapse/*',
            'src/node_modules/antd/lib/collapse/style/*',
            'src/node_modules/antd/lib/date-picker/*',
            'src/node_modules/antd/lib/date-picker/locale/*',
            'src/node_modules/antd/lib/date-picker/style/*',
            'src/node_modules/antd/lib/divider/*',
            'src/node_modules/antd/lib/divider/style/*',
            'src/node_modules/antd/lib/drawer/*',
            'src/node_modules/antd/lib/drawer/style/*',
            'src/node_modules/antd/lib/dropdown/*',
            'src/node_modules/antd/lib/dropdown/style/*',
            'src/node_modules/antd/lib/form/*',
            'src/node_modules/antd/lib/form/__tests__/*',
            'src/node_modules/antd/lib/form/style/*',
            'src/node_modules/antd/lib/grid/*',
            'src/node_modules/antd/lib/grid/style/*',
            'src/node_modules/antd/lib/icon/*',
            'src/node_modules/antd/lib/icon/style/*',
            'src/node_modules/antd/lib/input-number/*',
            'src/node_modules/antd/lib/input-number/style/*',
            'src/node_modules/antd/lib/input/*',
            'src/node_modules/antd/lib/input/style/*',
            'src/node_modules/antd/lib/layout/*',
            'src/node_modules/antd/lib/layout/style/*',
            'src/node_modules/antd/lib/list/*',
            'src/node_modules/antd/lib/list/style/*',
            'src/node_modules/antd/lib/locale-provider/*',
            'src/node_modules/antd/lib/locale-provider/style/*',
            'src/node_modules/antd/lib/mention/*',
            'src/node_modules/antd/lib/mention/style/*',
            'src/node_modules/antd/lib/menu/*',
            'src/node_modules/antd/lib/menu/style/*',
            'src/node_modules/antd/lib/message/*',
            'src/node_modules/antd/lib/message/style/*',
            'src/node_modules/antd/lib/modal/*',
            'src/node_modules/antd/lib/modal/style/*',
            'src/node_modules/antd/lib/notification/*',
            'src/node_modules/antd/lib/notification/style/*',
            'src/node_modules/antd/lib/pagination/*',
            'src/node_modules/antd/lib/pagination/style/*',
            'src/node_modules/antd/lib/popconfirm/*',
            'src/node_modules/antd/lib/popconfirm/style/*',
            'src/node_modules/antd/lib/popover/*',
            'src/node_modules/antd/lib/popover/style/*',
            'src/node_modules/antd/lib/progress/*',
            'src/node_modules/antd/lib/progress/style/*',
            'src/node_modules/antd/lib/radio/*',
            'src/node_modules/antd/lib/radio/style/*',
            'src/node_modules/antd/lib/rate/*',
            'src/node_modules/antd/lib/rate/style/*',
            'src/node_modules/antd/lib/row/*',
            'src/node_modules/antd/lib/row/style/*',
            'src/node_modules/antd/lib/select/*',
            'src/node_modules/antd/lib/select/style/*',
            'src/node_modules/antd/lib/skeleton/*',
            'src/node_modules/antd/lib/skeleton/style/*',
            'src/node_modules/antd/lib/slider/*',
            'src/node_modules/antd/lib/slider/style/*',
            'src/node_modules/antd/lib/spin/*',
            'src/node_modules/antd/lib/spin/style/*',
            'src/node_modules/antd/lib/steps/*',
            'src/node_modules/antd/lib/steps/style/*',
            'src/node_modules/antd/lib/style/*',
            'src/node_modules/antd/lib/style/color/*',
            'src/node_modules/antd/lib/style/core/*',
            'src/node_modules/antd/lib/style/core/motion/*',
            'src/node_modules/antd/lib/style/mixins/*',
            'src/node_modules/antd/lib/style/themes/*',
            'src/node_modules/antd/lib/switch/*',
            'src/node_modules/antd/lib/switch/style/*',
            'src/node_modules/antd/lib/table/*',
            'src/node_modules/antd/lib/table/style/*',
            'src/node_modules/antd/lib/tabs/*',
            'src/node_modules/antd/lib/tabs/style/*',
            'src/node_modules/antd/lib/tag/*',
            'src/node_modules/antd/lib/tag/style/*',
            'src/node_modules/antd/lib/time-picker/*',
            'src/node_modules/antd/lib/time-picker/locale/*',
            'src/node_modules/antd/lib/time-picker/style/*',
            'src/node_modules/antd/lib/timeline/*',
            'src/node_modules/antd/lib/timeline/style/*',
            'src/node_modules/antd/lib/tooltip/*',
            'src/node_modules/antd/lib/tooltip/style/*',
            'src/node_modules/antd/lib/transfer/*',
            'src/node_modules/antd/lib/transfer/style/*',
            'src/node_modules/antd/lib/tree-select/*',
            'src/node_modules/antd/lib/tree-select/style/*',
            'src/node_modules/antd/lib/tree/*',
            'src/node_modules/antd/lib/tree/style/*',
            'src/node_modules/antd/lib/upload/*',
            'src/node_modules/antd/lib/upload/style/*',
            'src/node_modules/antd/lib/version/*',
            'src/node_modules/antd/lib/version/style/*',
            'src/node_modules/antd/node_modules/*',
            'src/node_modules/antd/node_modules/classnames/*',
            'src/node_modules/antd/node_modules/core-js/*',
            'src/node_modules/antd/node_modules/core-js/build/*',
            'src/node_modules/antd/node_modules/core-js/client/*',
            'src/node_modules/antd/node_modules/core-js/core/*',
            'src/node_modules/antd/node_modules/core-js/es5/*',
            'src/node_modules/antd/node_modules/core-js/es6/*',
            'src/node_modules/antd/node_modules/core-js/es7/*',
            'src/node_modules/antd/node_modules/core-js/fn/*',
            'src/node_modules/antd/node_modules/core-js/fn/array/*',
            'src/node_modules/antd/node_modules/core-js/fn/function/*',
            'src/node_modules/antd/node_modules/core-js/fn/html-collection/*',
            'src/node_modules/antd/node_modules/core-js/fn/json/*',
            'src/node_modules/antd/node_modules/core-js/fn/math/*',
            'src/node_modules/antd/node_modules/core-js/fn/node-list/*',
            'src/node_modules/antd/node_modules/core-js/fn/number/*',
            'src/node_modules/antd/node_modules/core-js/fn/object/*',
            'src/node_modules/antd/node_modules/core-js/fn/reflect/*',
            'src/node_modules/antd/node_modules/core-js/fn/regexp/*',
            'src/node_modules/antd/node_modules/core-js/fn/string/*',
            'src/node_modules/antd/node_modules/core-js/fn/symbol/*',
            'src/node_modules/antd/node_modules/core-js/js/*',
            'src/node_modules/antd/node_modules/core-js/library/*',
            'src/node_modules/antd/node_modules/core-js/library/core/*',
            'src/node_modules/antd/node_modules/core-js/library/es5/*',
            'src/node_modules/antd/node_modules/core-js/library/es6/*',
            'src/node_modules/antd/node_modules/core-js/library/es7/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/array/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/function/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/html-collection/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/json/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/math/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/node-list/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/number/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/object/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/string/*',
            'src/node_modules/antd/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/antd/node_modules/core-js/library/js/*',
            'src/node_modules/antd/node_modules/core-js/library/modules/*',
            'src/node_modules/antd/node_modules/core-js/library/web/*',
            'src/node_modules/antd/node_modules/core-js/modules/*',
            'src/node_modules/antd/node_modules/core-js/modules/library/*',
            'src/node_modules/antd/node_modules/core-js/web/*',
            'src/node_modules/antd/node_modules/create-react-context/*',
            'src/node_modules/antd/node_modules/create-react-context/lib/*',
            'src/node_modules/antd/node_modules/fbjs/*',
            'src/node_modules/antd/node_modules/fbjs/flow/*',
            'src/node_modules/antd/node_modules/fbjs/flow/lib/*',
            'src/node_modules/antd/node_modules/fbjs/lib/*',
            'src/node_modules/antd/node_modules/fbjs/lib/__mocks__/*',
            'src/node_modules/antd/node_modules/fbjs/node_modules/*',
            'src/node_modules/antd/node_modules/fbjs/node_modules/.bin/*',
            'src/node_modules/antd/node_modules/lodash/*',
            'src/node_modules/antd/node_modules/lodash/fp/*',
            'src/node_modules/antd/node_modules/prop-types/*',
            'src/node_modules/antd/node_modules/prop-types/lib/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/flow/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/flow/lib/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/lib/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/lib/__mocks__/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/node_modules/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/fbjs/node_modules/.bin/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/ua-parser-js/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/ua-parser-js/dist/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/ua-parser-js/src/*',
            'src/node_modules/antd/node_modules/prop-types/node_modules/ua-parser-js/test/*',
            'src/node_modules/antd/node_modules/rc-form/*',
            'src/node_modules/antd/node_modules/rc-form/dist/*',
            'src/node_modules/antd/node_modules/rc-form/es/*',
            'src/node_modules/antd/node_modules/rc-form/lib/*',
            'src/node_modules/antd/node_modules/rc-form/node_modules/*',
            'src/node_modules/antd/node_modules/rc-form/node_modules/warning/*',
            'src/node_modules/antd/node_modules/rc-form/node_modules/warning/node_modules/*',
            'src/node_modules/antd/node_modules/rc-form/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/antd/node_modules/rc-trigger/*',
            'src/node_modules/antd/node_modules/rc-trigger/assets/*',
            'src/node_modules/antd/node_modules/rc-trigger/es/*',
            'src/node_modules/antd/node_modules/rc-trigger/lib/*',
            'src/node_modules/antd/node_modules/rc-trigger/node_modules/*',
            'src/node_modules/antd/node_modules/rc-trigger/node_modules/classnames/*',
            'src/node_modules/antd/node_modules/react-lifecycles-compat/*',
            'src/node_modules/antd/node_modules/ua-parser-js/*',
            'src/node_modules/antd/node_modules/ua-parser-js/dist/*',
            'src/node_modules/antd/node_modules/ua-parser-js/src/*',
            'src/node_modules/antd/node_modules/ua-parser-js/test/*',
            'src/node_modules/antd/node_modules/warning/*',
            'src/node_modules/antd/node_modules/warning/node_modules/*',
            'src/node_modules/antd/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/anymatch/*',
            'src/node_modules/aproba/*',
            'src/node_modules/are-we-there-yet/*',
            'src/node_modules/arr-diff/*',
            'src/node_modules/arr-flatten/*',
            'src/node_modules/arr-union/*',
            'src/node_modules/array-find-index/*',
            'src/node_modules/array-tree-filter/*',
            'src/node_modules/array-tree-filter/lib/*',
            'src/node_modules/array-unique/*',
            'src/node_modules/arraybuffer.slice/*',
            'src/node_modules/arraybuffer.slice/test/*',
            'src/node_modules/asap/*',
            'src/node_modules/asn1.js/*',
            'src/node_modules/asn1.js/lib/*',
            'src/node_modules/asn1.js/lib/asn1/*',
            'src/node_modules/asn1.js/lib/asn1/base/*',
            'src/node_modules/asn1.js/lib/asn1/constants/*',
            'src/node_modules/asn1.js/lib/asn1/decoders/*',
            'src/node_modules/asn1.js/lib/asn1/encoders/*',
            'src/node_modules/asn1/*',
            'src/node_modules/asn1/lib/*',
            'src/node_modules/asn1/lib/ber/*',
            'src/node_modules/asn1/tst/*',
            'src/node_modules/asn1/tst/ber/*',
            'src/node_modules/assert-plus/*',
            'src/node_modules/assert/*',
            'src/node_modules/assign-symbols/*',
            'src/node_modules/async-each/*',
            'src/node_modules/async-foreach/*',
            'src/node_modules/async-foreach/dist/*',
            'src/node_modules/async-foreach/lib/*',
            'src/node_modules/async-foreach/test/*',
            'src/node_modules/async-limiter/*',
            'src/node_modules/async-limiter/coverage/*',
            'src/node_modules/async-limiter/coverage/lcov-report/*',
            'src/node_modules/async-limiter/coverage/lcov-report/async-throttle/*',
            'src/node_modules/async-validator/*',
            'src/node_modules/async-validator/es/*',
            'src/node_modules/async-validator/es/rule/*',
            'src/node_modules/async-validator/es/validator/*',
            'src/node_modules/async-validator/lib/*',
            'src/node_modules/async-validator/lib/rule/*',
            'src/node_modules/async-validator/lib/validator/*',
            'src/node_modules/asynckit/*',
            'src/node_modules/asynckit/lib/*',
            'src/node_modules/atob/*',
            'src/node_modules/atob/bin/*',
            'src/node_modules/aws-sign2/*',
            'src/node_modules/aws4/*',
            'src/node_modules/babel-code-frame/*',
            'src/node_modules/babel-code-frame/lib/*',
            'src/node_modules/babel-code-frame/node_modules/*',
            'src/node_modules/babel-code-frame/node_modules/ansi-styles/*',
            'src/node_modules/babel-code-frame/node_modules/chalk/*',
            'src/node_modules/babel-code-frame/node_modules/supports-color/*',
            'src/node_modules/babel-loader/*',
            'src/node_modules/babel-loader/lib/*',
            'src/node_modules/babel-loader/node_modules/*',
            'src/node_modules/babel-loader/node_modules/.bin/*',
            'src/node_modules/babel-plugin-import/*',
            'src/node_modules/babel-plugin-import/lib/*',
            'src/node_modules/babel-runtime/*',
            'src/node_modules/babel-runtime/core-js/*',
            'src/node_modules/babel-runtime/core-js/array/*',
            'src/node_modules/babel-runtime/core-js/error/*',
            'src/node_modules/babel-runtime/core-js/json/*',
            'src/node_modules/babel-runtime/core-js/math/*',
            'src/node_modules/babel-runtime/core-js/number/*',
            'src/node_modules/babel-runtime/core-js/object/*',
            'src/node_modules/babel-runtime/core-js/reflect/*',
            'src/node_modules/babel-runtime/core-js/regexp/*',
            'src/node_modules/babel-runtime/core-js/string/*',
            'src/node_modules/babel-runtime/core-js/symbol/*',
            'src/node_modules/babel-runtime/core-js/system/*',
            'src/node_modules/babel-runtime/helpers/*',
            'src/node_modules/babel-runtime/node_modules/*',
            'src/node_modules/babel-runtime/node_modules/core-js/*',
            'src/node_modules/babel-runtime/node_modules/core-js/build/*',
            'src/node_modules/babel-runtime/node_modules/core-js/client/*',
            'src/node_modules/babel-runtime/node_modules/core-js/core/*',
            'src/node_modules/babel-runtime/node_modules/core-js/es5/*',
            'src/node_modules/babel-runtime/node_modules/core-js/es6/*',
            'src/node_modules/babel-runtime/node_modules/core-js/es7/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/array/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/array/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/date/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/dom-collections/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/error/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/function/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/function/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/json/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/math/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/number/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/number/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/object/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/promise/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/reflect/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/regexp/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/string/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/string/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/symbol/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/system/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/typed/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/weak-map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/fn/weak-set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/core/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/es5/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/es6/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/es7/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/array/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/array/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/date/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/dom-collections/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/error/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/function/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/function/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/json/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/math/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/number/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/number/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/object/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/promise/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/string/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/string/virtual/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/system/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/typed/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/weak-map/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/fn/weak-set/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/modules/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/stage/*',
            'src/node_modules/babel-runtime/node_modules/core-js/library/web/*',
            'src/node_modules/babel-runtime/node_modules/core-js/modules/*',
            'src/node_modules/babel-runtime/node_modules/core-js/modules/library/*',
            'src/node_modules/babel-runtime/node_modules/core-js/stage/*',
            'src/node_modules/babel-runtime/node_modules/core-js/web/*',
            'src/node_modules/babel-runtime/regenerator/*',
            'src/node_modules/backo2/*',
            'src/node_modules/backo2/test/*',
            'src/node_modules/balanced-match/*',
            'src/node_modules/base/*',
            'src/node_modules/base/node_modules/*',
            'src/node_modules/base/node_modules/define-property/*',
            'src/node_modules/base64-arraybuffer/*',
            'src/node_modules/base64-arraybuffer/lib/*',
            'src/node_modules/base64-js/*',
            'src/node_modules/base64-js/test/*',
            'src/node_modules/bcrypt-pbkdf/*',
            'src/node_modules/better-assert/*',
            'src/node_modules/big.js/*',
            'src/node_modules/binary-extensions/*',
            'src/node_modules/blob/*',
            'src/node_modules/blob/test/*',
            'src/node_modules/block-stream/*',
            'src/node_modules/bluebird/*',
            'src/node_modules/bluebird/js/*',
            'src/node_modules/bluebird/js/browser/*',
            'src/node_modules/bluebird/js/release/*',
            'src/node_modules/bn.js/*',
            'src/node_modules/bn.js/lib/*',
            'src/node_modules/bn.js/util/*',
            'src/node_modules/boom/*',
            'src/node_modules/boom/images/*',
            'src/node_modules/boom/lib/*',
            'src/node_modules/boom/node_modules/*',
            'src/node_modules/boom/node_modules/hoek/*',
            'src/node_modules/boom/node_modules/hoek/images/*',
            'src/node_modules/boom/node_modules/hoek/lib/*',
            'src/node_modules/boom/node_modules/hoek/test/*',
            'src/node_modules/boom/node_modules/hoek/test/modules/*',
            'src/node_modules/boom/test/*',
            'src/node_modules/brace-expansion/*',
            'src/node_modules/braces/*',
            'src/node_modules/braces/lib/*',
            'src/node_modules/brorand/*',
            'src/node_modules/brorand/test/*',
            'src/node_modules/browserify-aes/*',
            'src/node_modules/browserify-aes/modes/*',
            'src/node_modules/browserify-cipher/*',
            'src/node_modules/browserify-des/*',
            'src/node_modules/browserify-rsa/*',
            'src/node_modules/browserify-sign/*',
            'src/node_modules/browserify-sign/browser/*',
            'src/node_modules/browserify-zlib/*',
            'src/node_modules/browserify-zlib/lib/*',
            'src/node_modules/browserify-zlib/src/*',
            'src/node_modules/browserslist/*',
            'src/node_modules/buffer-from/*',
            'src/node_modules/buffer-xor/*',
            'src/node_modules/buffer-xor/test/*',
            'src/node_modules/buffer/*',
            'src/node_modules/buffer/bin/*',
            'src/node_modules/buffer/test/*',
            'src/node_modules/buffer/test/node/*',
            'src/node_modules/builtin-modules/*',
            'src/node_modules/builtin-status-codes/*',
            'src/node_modules/cacache/*',
            'src/node_modules/cacache/lib/*',
            'src/node_modules/cacache/lib/content/*',
            'src/node_modules/cacache/lib/util/*',
            'src/node_modules/cacache/locales/*',
            'src/node_modules/cacache/node_modules/*',
            'src/node_modules/cacache/node_modules/.bin/*',
            'src/node_modules/cacache/node_modules/lru-cache/*',
            'src/node_modules/cache-base/*',
            'src/node_modules/callsite/*',
            'src/node_modules/camelcase-keys/*',
            'src/node_modules/camelcase-keys/node_modules/*',
            'src/node_modules/camelcase-keys/node_modules/camelcase/*',
            'src/node_modules/camelcase/*',
            'src/node_modules/caniuse-lite/*',
            'src/node_modules/caniuse-lite/data/*',
            'src/node_modules/caniuse-lite/data/features/*',
            'src/node_modules/caniuse-lite/data/regions/*',
            'src/node_modules/caniuse-lite/dist/*',
            'src/node_modules/caniuse-lite/dist/lib/*',
            'src/node_modules/caniuse-lite/dist/unpacker/*',
            'src/node_modules/caseless/*',
            'src/node_modules/chalk/*',
            'src/node_modules/chalk/types/*',
            'src/node_modules/chokidar/*',
            'src/node_modules/chokidar/lib/*',
            'src/node_modules/chownr/*',
            'src/node_modules/chrome-trace-event/*',
            'src/node_modules/chrome-trace-event/dist/*',
            'src/node_modules/cipher-base/*',
            'src/node_modules/class-utils/*',
            'src/node_modules/classnames/*',
            'src/node_modules/cliui/*',
            'src/node_modules/cliui/node_modules/*',
            'src/node_modules/cliui/node_modules/ansi-regex/*',
            'src/node_modules/cliui/node_modules/is-fullwidth-code-point/*',
            'src/node_modules/cliui/node_modules/string-width/*',
            'src/node_modules/cliui/node_modules/strip-ansi/*',
            'src/node_modules/clone-deep/*',
            'src/node_modules/clone/*',
            'src/node_modules/co/*',
            'src/node_modules/code-point-at/*',
            'src/node_modules/collection-visit/*',
            'src/node_modules/color-convert/*',
            'src/node_modules/color-name/*',
            'src/node_modules/combined-stream/*',
            'src/node_modules/combined-stream/lib/*',
            'src/node_modules/commander/*',
            'src/node_modules/commander/typings/*',
            'src/node_modules/commondir/*',
            'src/node_modules/commondir/example/*',
            'src/node_modules/commondir/test/*',
            'src/node_modules/component-bind/*',
            'src/node_modules/component-classes/*',
            'src/node_modules/component-emitter/*',
            'src/node_modules/component-indexof/*',
            'src/node_modules/component-indexof/test/*',
            'src/node_modules/component-inherit/*',
            'src/node_modules/component-inherit/test/*',
            'src/node_modules/compression-webpack-plugin/*',
            'src/node_modules/compression-webpack-plugin/dist/*',
            'src/node_modules/compression-webpack-plugin/node_modules/*',
            'src/node_modules/compression-webpack-plugin/node_modules/.bin/*',
            'src/node_modules/compression-webpack-plugin/node_modules/find-cache-dir/*',
            'src/node_modules/compression-webpack-plugin/node_modules/schema-utils/*',
            'src/node_modules/compression-webpack-plugin/node_modules/schema-utils/src/*',
            'src/node_modules/concat-map/*',
            'src/node_modules/concat-map/example/*',
            'src/node_modules/concat-map/test/*',
            'src/node_modules/concat-stream/*',
            'src/node_modules/console-browserify/*',
            'src/node_modules/console-browserify/test/*',
            'src/node_modules/console-browserify/test/static/*',
            'src/node_modules/console-control-strings/*',
            'src/node_modules/constants-browserify/*',
            'src/node_modules/convert-source-map/*',
            'src/node_modules/copy-concurrently/*',
            'src/node_modules/copy-concurrently/node_modules/*',
            'src/node_modules/copy-concurrently/node_modules/.bin/*',
            'src/node_modules/copy-descriptor/*',
            'src/node_modules/core-js/*',
            'src/node_modules/core-js/build/*',
            'src/node_modules/core-js/client/*',
            'src/node_modules/core-js/core/*',
            'src/node_modules/core-js/es5/*',
            'src/node_modules/core-js/es6/*',
            'src/node_modules/core-js/es7/*',
            'src/node_modules/core-js/fn/*',
            'src/node_modules/core-js/fn/array/*',
            'src/node_modules/core-js/fn/array/virtual/*',
            'src/node_modules/core-js/fn/date/*',
            'src/node_modules/core-js/fn/dom-collections/*',
            'src/node_modules/core-js/fn/error/*',
            'src/node_modules/core-js/fn/function/*',
            'src/node_modules/core-js/fn/function/virtual/*',
            'src/node_modules/core-js/fn/json/*',
            'src/node_modules/core-js/fn/map/*',
            'src/node_modules/core-js/fn/math/*',
            'src/node_modules/core-js/fn/number/*',
            'src/node_modules/core-js/fn/number/virtual/*',
            'src/node_modules/core-js/fn/object/*',
            'src/node_modules/core-js/fn/promise/*',
            'src/node_modules/core-js/fn/reflect/*',
            'src/node_modules/core-js/fn/regexp/*',
            'src/node_modules/core-js/fn/set/*',
            'src/node_modules/core-js/fn/string/*',
            'src/node_modules/core-js/fn/string/virtual/*',
            'src/node_modules/core-js/fn/symbol/*',
            'src/node_modules/core-js/fn/system/*',
            'src/node_modules/core-js/fn/typed/*',
            'src/node_modules/core-js/fn/weak-map/*',
            'src/node_modules/core-js/fn/weak-set/*',
            'src/node_modules/core-js/library/*',
            'src/node_modules/core-js/library/core/*',
            'src/node_modules/core-js/library/es5/*',
            'src/node_modules/core-js/library/es6/*',
            'src/node_modules/core-js/library/es7/*',
            'src/node_modules/core-js/library/fn/*',
            'src/node_modules/core-js/library/fn/array/*',
            'src/node_modules/core-js/library/fn/array/virtual/*',
            'src/node_modules/core-js/library/fn/date/*',
            'src/node_modules/core-js/library/fn/dom-collections/*',
            'src/node_modules/core-js/library/fn/error/*',
            'src/node_modules/core-js/library/fn/function/*',
            'src/node_modules/core-js/library/fn/function/virtual/*',
            'src/node_modules/core-js/library/fn/json/*',
            'src/node_modules/core-js/library/fn/map/*',
            'src/node_modules/core-js/library/fn/math/*',
            'src/node_modules/core-js/library/fn/number/*',
            'src/node_modules/core-js/library/fn/number/virtual/*',
            'src/node_modules/core-js/library/fn/object/*',
            'src/node_modules/core-js/library/fn/promise/*',
            'src/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/core-js/library/fn/set/*',
            'src/node_modules/core-js/library/fn/string/*',
            'src/node_modules/core-js/library/fn/string/virtual/*',
            'src/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/core-js/library/fn/system/*',
            'src/node_modules/core-js/library/fn/typed/*',
            'src/node_modules/core-js/library/fn/weak-map/*',
            'src/node_modules/core-js/library/fn/weak-set/*',
            'src/node_modules/core-js/library/modules/*',
            'src/node_modules/core-js/library/stage/*',
            'src/node_modules/core-js/library/web/*',
            'src/node_modules/core-js/modules/*',
            'src/node_modules/core-js/modules/library/*',
            'src/node_modules/core-js/stage/*',
            'src/node_modules/core-js/web/*',
            'src/node_modules/core-util-is/*',
            'src/node_modules/core-util-is/lib/*',
            'src/node_modules/create-ecdh/*',
            'src/node_modules/create-hash/*',
            'src/node_modules/create-hash/node_modules/*',
            'src/node_modules/create-hash/node_modules/.bin/*',
            'src/node_modules/create-hmac/*',
            'src/node_modules/create-hmac/node_modules/*',
            'src/node_modules/create-hmac/node_modules/.bin/*',
            'src/node_modules/create-react-class/*',
            'src/node_modules/create-react-class/node_modules/*',
            'src/node_modules/create-react-class/node_modules/.bin/*',
            'src/node_modules/cross-spawn/*',
            'src/node_modules/cross-spawn/lib/*',
            'src/node_modules/cross-spawn/lib/util/*',
            'src/node_modules/cross-spawn/node_modules/*',
            'src/node_modules/cross-spawn/node_modules/.bin/*',
            'src/node_modules/cryptiles/*',
            'src/node_modules/cryptiles/lib/*',
            'src/node_modules/cryptiles/test/*',
            'src/node_modules/crypto-browserify/*',
            'src/node_modules/crypto-browserify/example/*',
            'src/node_modules/crypto-browserify/test/*',
            'src/node_modules/crypto-browserify/test/node/*',
            'src/node_modules/css-animation/*',
            'src/node_modules/css-animation/es/*',
            'src/node_modules/css-animation/lib/*',
            'src/node_modules/css-loader/*',
            'src/node_modules/css-loader/lib/*',
            'src/node_modules/css-loader/lib/url/*',
            'src/node_modules/css-loader/node_modules/*',
            'src/node_modules/css-loader/node_modules/.bin/*',
            'src/node_modules/css-loader/node_modules/postcss/*',
            'src/node_modules/css-loader/node_modules/postcss/docs/*',
            'src/node_modules/css-loader/node_modules/postcss/docs/guidelines/*',
            'src/node_modules/css-loader/node_modules/postcss/lib/*',
            'src/node_modules/css-loader/node_modules/supports-color/*',
            'src/node_modules/css-selector-tokenizer/*',
            'src/node_modules/css-selector-tokenizer/lib/*',
            'src/node_modules/css-selector-tokenizer/node_modules/*',
            'src/node_modules/css-selector-tokenizer/node_modules/.bin/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regenerate/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regexpu-core/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regexpu-core/data/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regexpu-core/node_modules/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regexpu-core/node_modules/.bin/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regjsgen/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regjsparser/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regjsparser/bin/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regjsparser/node_modules/*',
            'src/node_modules/css-selector-tokenizer/node_modules/regjsparser/node_modules/.bin/*',
            'src/node_modules/cssesc/*',
            'src/node_modules/cssesc/bin/*',
            'src/node_modules/cssesc/man/*',
            'src/node_modules/currently-unhandled/*',
            'src/node_modules/cyclist/*',
            'src/node_modules/dashdash/*',
            'src/node_modules/dashdash/etc/*',
            'src/node_modules/dashdash/lib/*',
            'src/node_modules/date-now/*',
            'src/node_modules/date-now/test/*',
            'src/node_modules/date-now/test/static/*',
            'src/node_modules/debug/*',
            'src/node_modules/debug/src/*',
            'src/node_modules/decamelize/*',
            'src/node_modules/decode-uri-component/*',
            'src/node_modules/deep-extend/*',
            'src/node_modules/deep-extend/lib/*',
            'src/node_modules/define-properties/*',
            'src/node_modules/define-properties/test/*',
            'src/node_modules/define-property/*',
            'src/node_modules/define-property/node_modules/*',
            'src/node_modules/define-property/node_modules/is-accessor-descriptor/*',
            'src/node_modules/define-property/node_modules/is-accessor-descriptor/node_modules/*',
            'src/node_modules/define-property/node_modules/is-accessor-descriptor/node_modules/kind-of/*',
            'src/node_modules/define-property/node_modules/is-data-descriptor/*',
            'src/node_modules/define-property/node_modules/is-data-descriptor/node_modules/*',
            'src/node_modules/define-property/node_modules/is-data-descriptor/node_modules/kind-of/*',
            'src/node_modules/define-property/node_modules/is-descriptor/*',
            'src/node_modules/define-property/node_modules/kind-of/*',
            'src/node_modules/delayed-stream/*',
            'src/node_modules/delayed-stream/lib/*',
            'src/node_modules/delegates/*',
            'src/node_modules/delegates/test/*',
            'src/node_modules/des.js/*',
            'src/node_modules/des.js/lib/*',
            'src/node_modules/des.js/lib/des/*',
            'src/node_modules/des.js/test/*',
            'src/node_modules/detect-libc/*',
            'src/node_modules/detect-libc/bin/*',
            'src/node_modules/detect-libc/lib/*',
            'src/node_modules/diffie-hellman/*',
            'src/node_modules/diffie-hellman/lib/*',
            'src/node_modules/diffie-hellman/node_modules/*',
            'src/node_modules/diffie-hellman/node_modules/.bin/*',
            'src/node_modules/dom-align/*',
            'src/node_modules/dom-align/es/*',
            'src/node_modules/dom-align/es/align/*',
            'src/node_modules/dom-align/lib/*',
            'src/node_modules/dom-align/lib/align/*',
            'src/node_modules/dom-closest/*',
            'src/node_modules/dom-matches/*',
            'src/node_modules/dom-scroll-into-view/*',
            'src/node_modules/dom-scroll-into-view/lib/*',
            'src/node_modules/domain-browser/*',
            'src/node_modules/domain-browser/source/*',
            'src/node_modules/draft-js/*',
            'src/node_modules/draft-js/dist/*',
            'src/node_modules/draft-js/lib/*',
            'src/node_modules/draft-js/node_modules/*',
            'src/node_modules/draft-js/node_modules/immutable/*',
            'src/node_modules/draft-js/node_modules/immutable/contrib/*',
            'src/node_modules/draft-js/node_modules/immutable/contrib/cursor/*',
            'src/node_modules/draft-js/node_modules/immutable/contrib/cursor/__tests__/*',
            'src/node_modules/draft-js/node_modules/immutable/dist/*',
            'src/node_modules/duplexify/*',
            'src/node_modules/ecc-jsbn/*',
            'src/node_modules/ecc-jsbn/lib/*',
            'src/node_modules/electron-to-chromium/*',
            'src/node_modules/elliptic/*',
            'src/node_modules/elliptic/lib/*',
            'src/node_modules/elliptic/lib/elliptic/*',
            'src/node_modules/elliptic/lib/elliptic/curve/*',
            'src/node_modules/elliptic/lib/elliptic/ec/*',
            'src/node_modules/elliptic/lib/elliptic/eddsa/*',
            'src/node_modules/elliptic/lib/elliptic/precomputed/*',
            'src/node_modules/emojis-list/*',
            'src/node_modules/encoding/*',
            'src/node_modules/encoding/lib/*',
            'src/node_modules/encoding/test/*',
            'src/node_modules/end-of-stream/*',
            'src/node_modules/engine.io-client/*',
            'src/node_modules/engine.io-client/lib/*',
            'src/node_modules/engine.io-client/lib/transports/*',
            'src/node_modules/engine.io-parser/*',
            'src/node_modules/engine.io-parser/lib/*',
            'src/node_modules/enhanced-resolve/*',
            'src/node_modules/enhanced-resolve/lib/*',
            'src/node_modules/enhanced-resolve/node_modules/*',
            'src/node_modules/enhanced-resolve/node_modules/tapable/*',
            'src/node_modules/enhanced-resolve/node_modules/tapable/lib/*',
            'src/node_modules/enhanced-resolve/node_modules/tapable/lib/__tests__/*',
            'src/node_modules/enhanced-resolve/node_modules/tapable/lib/__tests__/__snapshots__/*',
            'src/node_modules/enquire.js/*',
            'src/node_modules/enquire.js/dist/*',
            'src/node_modules/enquire.js/src/*',
            'src/node_modules/errno/*',
            'src/node_modules/error-ex/*',
            'src/node_modules/es-abstract/*',
            'src/node_modules/es-abstract/helpers/*',
            'src/node_modules/es-abstract/operations/*',
            'src/node_modules/es-abstract/test/*',
            'src/node_modules/es-abstract/test/helpers/*',
            'src/node_modules/es-to-primitive/*',
            'src/node_modules/es-to-primitive/helpers/*',
            'src/node_modules/es-to-primitive/test/*',
            'src/node_modules/escape-string-regexp/*',
            'src/node_modules/eslint-scope/*',
            'src/node_modules/eslint-scope/lib/*',
            'src/node_modules/esrecurse/*',
            'src/node_modules/estraverse/*',
            'src/node_modules/esutils/*',
            'src/node_modules/esutils/lib/*',
            'src/node_modules/event-lite/*',
            'src/node_modules/event-lite/assets/*',
            'src/node_modules/event-lite/dist/*',
            'src/node_modules/event-lite/test/*',
            'src/node_modules/event-lite/test/zuul/*',
            'src/node_modules/eventlistener/*',
            'src/node_modules/events/*',
            'src/node_modules/events/tests/*',
            'src/node_modules/evp_bytestokey/*',
            'src/node_modules/execa/*',
            'src/node_modules/execa/lib/*',
            'src/node_modules/expand-brackets/*',
            'src/node_modules/expand-brackets/lib/*',
            'src/node_modules/expand-brackets/node_modules/*',
            'src/node_modules/expand-brackets/node_modules/debug/*',
            'src/node_modules/expand-brackets/node_modules/debug/src/*',
            'src/node_modules/extend-shallow/*',
            'src/node_modules/extend/*',
            'src/node_modules/extglob/*',
            'src/node_modules/extglob/lib/*',
            'src/node_modules/extglob/node_modules/*',
            'src/node_modules/extglob/node_modules/define-property/*',
            'src/node_modules/extsprintf/*',
            'src/node_modules/extsprintf/lib/*',
            'src/node_modules/fast-deep-equal/*',
            'src/node_modules/fast-json-stable-stringify/*',
            'src/node_modules/fast-json-stable-stringify/benchmark/*',
            'src/node_modules/fast-json-stable-stringify/example/*',
            'src/node_modules/fast-json-stable-stringify/test/*',
            'src/node_modules/fastparse/*',
            'src/node_modules/fastparse/lib/*',
            'src/node_modules/fastparse/test/*',
            'src/node_modules/fbjs/*',
            'src/node_modules/fbjs/flow/*',
            'src/node_modules/fbjs/flow/lib/*',
            'src/node_modules/fbjs/lib/*',
            'src/node_modules/fbjs/lib/__mocks__/*',
            'src/node_modules/fbjs/node_modules/*',
            'src/node_modules/fbjs/node_modules/.bin/*',
            'src/node_modules/fbjs/node_modules/core-js/*',
            'src/node_modules/fbjs/node_modules/core-js/build/*',
            'src/node_modules/fbjs/node_modules/core-js/client/*',
            'src/node_modules/fbjs/node_modules/core-js/core/*',
            'src/node_modules/fbjs/node_modules/core-js/es5/*',
            'src/node_modules/fbjs/node_modules/core-js/es6/*',
            'src/node_modules/fbjs/node_modules/core-js/es7/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/array/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/function/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/html-collection/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/json/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/math/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/node-list/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/number/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/object/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/reflect/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/regexp/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/string/*',
            'src/node_modules/fbjs/node_modules/core-js/fn/symbol/*',
            'src/node_modules/fbjs/node_modules/core-js/js/*',
            'src/node_modules/fbjs/node_modules/core-js/library/*',
            'src/node_modules/fbjs/node_modules/core-js/library/core/*',
            'src/node_modules/fbjs/node_modules/core-js/library/es5/*',
            'src/node_modules/fbjs/node_modules/core-js/library/es6/*',
            'src/node_modules/fbjs/node_modules/core-js/library/es7/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/array/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/function/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/html-collection/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/json/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/math/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/node-list/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/number/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/object/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/reflect/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/regexp/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/string/*',
            'src/node_modules/fbjs/node_modules/core-js/library/fn/symbol/*',
            'src/node_modules/fbjs/node_modules/core-js/library/js/*',
            'src/node_modules/fbjs/node_modules/core-js/library/modules/*',
            'src/node_modules/fbjs/node_modules/core-js/library/web/*',
            'src/node_modules/fbjs/node_modules/core-js/modules/*',
            'src/node_modules/fbjs/node_modules/core-js/modules/library/*',
            'src/node_modules/fbjs/node_modules/core-js/web/*',
            'src/node_modules/figgy-pudding/*',
            'src/node_modules/fill-range/*',
            'src/node_modules/find-cache-dir/*',
            'src/node_modules/find-cache-dir/node_modules/*',
            'src/node_modules/find-cache-dir/node_modules/find-up/*',
            'src/node_modules/find-cache-dir/node_modules/locate-path/*',
            'src/node_modules/find-cache-dir/node_modules/p-limit/*',
            'src/node_modules/find-cache-dir/node_modules/p-locate/*',
            'src/node_modules/find-cache-dir/node_modules/p-try/*',
            'src/node_modules/find-cache-dir/node_modules/pkg-dir/*',
            'src/node_modules/find-up/*',
            'src/node_modules/flush-write-stream/*',
            'src/node_modules/for-in/*',
            'src/node_modules/for-own/*',
            'src/node_modules/foreach/*',
            'src/node_modules/forever-agent/*',
            'src/node_modules/form-data/*',
            'src/node_modules/form-data/lib/*',
            'src/node_modules/fragment-cache/*',
            'src/node_modules/from2/*',
            'src/node_modules/fs-write-stream-atomic/*',
            'src/node_modules/fs-write-stream-atomic/test/*',
            'src/node_modules/fs.realpath/*',
            'src/node_modules/fstream-ignore/*',
            'src/node_modules/fstream/*',
            'src/node_modules/fstream/examples/*',
            'src/node_modules/fstream/lib/*',
            'src/node_modules/fstream/node_modules/*',
            'src/node_modules/fstream/node_modules/.bin/*',
            'src/node_modules/function-bind/*',
            'src/node_modules/function-bind/test/*',
            'src/node_modules/gauge/*',
            'src/node_modules/gaze/*',
            'src/node_modules/gaze/lib/*',
            'src/node_modules/get-caller-file/*',
            'src/node_modules/get-stdin/*',
            'src/node_modules/get-stream/*',
            'src/node_modules/get-value/*',
            'src/node_modules/getpass/*',
            'src/node_modules/getpass/lib/*',
            'src/node_modules/glob-parent/*',
            'src/node_modules/glob-parent/node_modules/*',
            'src/node_modules/glob-parent/node_modules/is-glob/*',
            'src/node_modules/glob/*',
            'src/node_modules/global-modules-path/*',
            'src/node_modules/global-modules-path/lib/*',
            'src/node_modules/globals/*',
            'src/node_modules/globule/*',
            'src/node_modules/globule/lib/*',
            'src/node_modules/globule/node_modules/*',
            'src/node_modules/globule/node_modules/lodash/*',
            'src/node_modules/globule/node_modules/lodash/fp/*',
            'src/node_modules/graceful-fs/*',
            'src/node_modules/gud/*',
            'src/node_modules/hammerjs/*',
            'src/node_modules/hammerjs/src/*',
            'src/node_modules/hammerjs/src/input/*',
            'src/node_modules/hammerjs/src/recognizers/*',
            'src/node_modules/hammerjs/tests/*',
            'src/node_modules/hammerjs/tests/manual/*',
            'src/node_modules/hammerjs/tests/manual/assets/*',
            'src/node_modules/hammerjs/tests/unit/*',
            'src/node_modules/hammerjs/tests/unit/assets/*',
            'src/node_modules/hammerjs/tests/unit/gestures/*',
            'src/node_modules/har-schema/*',
            'src/node_modules/har-schema/lib/*',
            'src/node_modules/har-validator/*',
            'src/node_modules/har-validator/lib/*',
            'src/node_modules/har-validator/node_modules/*',
            'src/node_modules/har-validator/node_modules/ajv/*',
            'src/node_modules/har-validator/node_modules/ajv/dist/*',
            'src/node_modules/har-validator/node_modules/ajv/lib/*',
            'src/node_modules/har-validator/node_modules/ajv/lib/compile/*',
            'src/node_modules/har-validator/node_modules/ajv/lib/dot/*',
            'src/node_modules/har-validator/node_modules/ajv/lib/dotjs/*',
            'src/node_modules/har-validator/node_modules/ajv/lib/refs/*',
            'src/node_modules/har-validator/node_modules/ajv/scripts/*',
            'src/node_modules/has-ansi/*',
            'src/node_modules/has-binary2/*',
            'src/node_modules/has-binary2/node_modules/*',
            'src/node_modules/has-binary2/node_modules/isarray/*',
            'src/node_modules/has-cors/*',
            'src/node_modules/has-flag/*',
            'src/node_modules/has-unicode/*',
            'src/node_modules/has-value/*',
            'src/node_modules/has-values/*',
            'src/node_modules/has-values/node_modules/*',
            'src/node_modules/has-values/node_modules/kind-of/*',
            'src/node_modules/has/*',
            'src/node_modules/has/src/*',
            'src/node_modules/has/test/*',
            'src/node_modules/hash-base/*',
            'src/node_modules/hash.js/*',
            'src/node_modules/hash.js/lib/*',
            'src/node_modules/hash.js/lib/hash/*',
            'src/node_modules/hash.js/lib/hash/sha/*',
            'src/node_modules/hash.js/test/*',
            'src/node_modules/hawk/*',
            'src/node_modules/hawk/dist/*',
            'src/node_modules/hawk/example/*',
            'src/node_modules/hawk/images/*',
            'src/node_modules/hawk/lib/*',
            'src/node_modules/hawk/node_modules/*',
            'src/node_modules/hawk/node_modules/hoek/*',
            'src/node_modules/hawk/node_modules/hoek/images/*',
            'src/node_modules/hawk/node_modules/hoek/lib/*',
            'src/node_modules/hawk/node_modules/hoek/test/*',
            'src/node_modules/hawk/node_modules/hoek/test/modules/*',
            'src/node_modules/hawk/test/*',
            'src/node_modules/history/*',
            'src/node_modules/history/es/*',
            'src/node_modules/history/node_modules/*',
            'src/node_modules/history/node_modules/.bin/*',
            'src/node_modules/history/umd/*',
            'src/node_modules/hmac-drbg/*',
            'src/node_modules/hmac-drbg/lib/*',
            'src/node_modules/hmac-drbg/test/*',
            'src/node_modules/hmac-drbg/test/fixtures/*',
            'src/node_modules/hoek/*',
            'src/node_modules/hoek/lib/*',
            'src/node_modules/hoist-non-react-statics/*',
            'src/node_modules/hosted-git-info/*',
            'src/node_modules/http-signature/*',
            'src/node_modules/http-signature/lib/*',
            'src/node_modules/http-signature/node_modules/*',
            'src/node_modules/http-signature/node_modules/.bin/*',
            'src/node_modules/https-browserify/*',
            'src/node_modules/iconv-lite/*',
            'src/node_modules/iconv-lite/encodings/*',
            'src/node_modules/iconv-lite/encodings/tables/*',
            'src/node_modules/iconv-lite/lib/*',
            'src/node_modules/icss-replace-symbols/*',
            'src/node_modules/icss-replace-symbols/lib/*',
            'src/node_modules/icss-utils/*',
            'src/node_modules/icss-utils/lib/*',
            'src/node_modules/ieee754/*',
            'src/node_modules/ieee754/test/*',
            'src/node_modules/iferr/*',
            'src/node_modules/iferr/test/*',
            'src/node_modules/image-size/*',
            'src/node_modules/image-size/bin/*',
            'src/node_modules/image-size/lib/*',
            'src/node_modules/image-size/lib/types/*',
            'src/node_modules/immutable/*',
            'src/node_modules/immutable/contrib/*',
            'src/node_modules/immutable/contrib/cursor/*',
            'src/node_modules/immutable/contrib/cursor/__tests__/*',
            'src/node_modules/immutable/dist/*',
            'src/node_modules/import-local/*',
            'src/node_modules/import-local/fixtures/*',
            'src/node_modules/imurmurhash/*',
            'src/node_modules/in-publish/*',
            'src/node_modules/in-publish/test/*',
            'src/node_modules/indent-string/*',
            'src/node_modules/indexof/*',
            'src/node_modules/inflight/*',
            'src/node_modules/inherits/*',
            'src/node_modules/ini/*',
            'src/node_modules/int64-buffer/*',
            'src/node_modules/int64-buffer/dist/*',
            'src/node_modules/int64-buffer/test/*',
            'src/node_modules/int64-buffer/test/zuul/*',
            'src/node_modules/interpret/*',
            'src/node_modules/intersperse/*',
            'src/node_modules/intersperse/lib/*',
            'src/node_modules/intersperse/test/*',
            'src/node_modules/invariant/*',
            'src/node_modules/invariant/node_modules/*',
            'src/node_modules/invariant/node_modules/.bin/*',
            'src/node_modules/invert-kv/*',
            'src/node_modules/is-accessor-descriptor/*',
            'src/node_modules/is-arrayish/*',
            'src/node_modules/is-binary-path/*',
            'src/node_modules/is-buffer/*',
            'src/node_modules/is-buffer/test/*',
            'src/node_modules/is-builtin-module/*',
            'src/node_modules/is-callable/*',
            'src/node_modules/is-data-descriptor/*',
            'src/node_modules/is-date-object/*',
            'src/node_modules/is-descriptor/*',
            'src/node_modules/is-extendable/*',
            'src/node_modules/is-extglob/*',
            'src/node_modules/is-finite/*',
            'src/node_modules/is-fullwidth-code-point/*',
            'src/node_modules/is-glob/*',
            'src/node_modules/is-negative-zero/*',
            'src/node_modules/is-number/*',
            'src/node_modules/is-number/node_modules/*',
            'src/node_modules/is-number/node_modules/kind-of/*',
            'src/node_modules/is-odd/*',
            'src/node_modules/is-odd/node_modules/*',
            'src/node_modules/is-odd/node_modules/is-number/*',
            'src/node_modules/is-plain-object/*',
            'src/node_modules/is-regex/*',
            'src/node_modules/is-stream/*',
            'src/node_modules/is-symbol/*',
            'src/node_modules/is-symbol/test/*',
            'src/node_modules/is-typedarray/*',
            'src/node_modules/is-utf8/*',
            'src/node_modules/is-windows/*',
            'src/node_modules/isarray/*',
            'src/node_modules/isexe/*',
            'src/node_modules/isexe/test/*',
            'src/node_modules/isobject/*',
            'src/node_modules/isomorphic-fetch/*',
            'src/node_modules/isomorphic-fetch/test/*',
            'src/node_modules/isstream/*',
            'src/node_modules/js-base64/*',
            'src/node_modules/js-base64/old/*',
            'src/node_modules/js-base64/test-moment/*',
            'src/node_modules/js-base64/test/*',
            'src/node_modules/js-levenshtein/*',
            'src/node_modules/js-tokens/*',
            'src/node_modules/jsbn/*',
            'src/node_modules/jsesc/*',
            'src/node_modules/jsesc/bin/*',
            'src/node_modules/jsesc/man/*',
            'src/node_modules/json-parse-better-errors/*',
            'src/node_modules/json-schema-traverse/*',
            'src/node_modules/json-schema-traverse/spec/*',
            'src/node_modules/json-schema-traverse/spec/fixtures/*',
            'src/node_modules/json-schema/*',
            'src/node_modules/json-schema/draft-00/*',
            'src/node_modules/json-schema/draft-01/*',
            'src/node_modules/json-schema/draft-02/*',
            'src/node_modules/json-schema/draft-03/*',
            'src/node_modules/json-schema/draft-03/examples/*',
            'src/node_modules/json-schema/draft-04/*',
            'src/node_modules/json-schema/lib/*',
            'src/node_modules/json-schema/test/*',
            'src/node_modules/json-stable-stringify/*',
            'src/node_modules/json-stable-stringify/example/*',
            'src/node_modules/json-stable-stringify/test/*',
            'src/node_modules/json-stringify-safe/*',
            'src/node_modules/json-stringify-safe/test/*',
            'src/node_modules/json2mq/*',
            'src/node_modules/json2mq/test/*',
            'src/node_modules/json5/*',
            'src/node_modules/json5/lib/*',
            'src/node_modules/jsonify/*',
            'src/node_modules/jsonify/lib/*',
            'src/node_modules/jsonify/test/*',
            'src/node_modules/jsprim/*',
            'src/node_modules/jsprim/lib/*',
            'src/node_modules/kind-of/*',
            'src/node_modules/lcid/*',
            'src/node_modules/less-loader/*',
            'src/node_modules/less-loader/dist/*',
            'src/node_modules/less-loader/node_modules/*',
            'src/node_modules/less-loader/node_modules/.bin/*',
            'src/node_modules/less/*',
            'src/node_modules/less/.github/*',
            'src/node_modules/less/.vscode/*',
            'src/node_modules/less/bin/*',
            'src/node_modules/less/dist/*',
            'src/node_modules/less/lib/*',
            'src/node_modules/less/lib/less-browser/*',
            'src/node_modules/less/lib/less-node/*',
            'src/node_modules/less/lib/less/*',
            'src/node_modules/less/lib/less/data/*',
            'src/node_modules/less/lib/less/environment/*',
            'src/node_modules/less/lib/less/functions/*',
            'src/node_modules/less/lib/less/parser/*',
            'src/node_modules/less/lib/less/tree/*',
            'src/node_modules/less/lib/less/visitors/*',
            'src/node_modules/less/lib/source-map/*',
            'src/node_modules/less/node_modules/*',
            'src/node_modules/less/node_modules/.bin/*',
            'src/node_modules/less/node_modules/boom/*',
            'src/node_modules/less/node_modules/boom/lib/*',
            'src/node_modules/less/node_modules/cryptiles/*',
            'src/node_modules/less/node_modules/cryptiles/lib/*',
            'src/node_modules/less/node_modules/cryptiles/node_modules/*',
            'src/node_modules/less/node_modules/cryptiles/node_modules/boom/*',
            'src/node_modules/less/node_modules/cryptiles/node_modules/boom/lib/*',
            'src/node_modules/less/node_modules/hawk/*',
            'src/node_modules/less/node_modules/hawk/dist/*',
            'src/node_modules/less/node_modules/hawk/lib/*',
            'src/node_modules/less/node_modules/request/*',
            'src/node_modules/less/node_modules/request/lib/*',
            'src/node_modules/less/node_modules/request/node_modules/*',
            'src/node_modules/less/node_modules/request/node_modules/.bin/*',
            'src/node_modules/less/node_modules/sntp/*',
            'src/node_modules/less/node_modules/sntp/lib/*',
            'src/node_modules/less/test/*',
            'src/node_modules/less/test/browser/*',
            'src/node_modules/less/test/browser/css/*',
            'src/node_modules/less/test/browser/css/global-vars/*',
            'src/node_modules/less/test/browser/css/modify-vars/*',
            'src/node_modules/less/test/browser/css/plugin/*',
            'src/node_modules/less/test/browser/css/postProcessor/*',
            'src/node_modules/less/test/browser/css/relative-urls/*',
            'src/node_modules/less/test/browser/css/rewrite-urls/*',
            'src/node_modules/less/test/browser/css/rootpath-relative/*',
            'src/node_modules/less/test/browser/css/rootpath-rewrite-urls/*',
            'src/node_modules/less/test/browser/css/rootpath/*',
            'src/node_modules/less/test/browser/less/*',
            'src/node_modules/less/test/browser/less/console-errors/*',
            'src/node_modules/less/test/browser/less/errors/*',
            'src/node_modules/less/test/browser/less/global-vars/*',
            'src/node_modules/less/test/browser/less/imports/*',
            'src/node_modules/less/test/browser/less/modify-vars/*',
            'src/node_modules/less/test/browser/less/modify-vars/imports/*',
            'src/node_modules/less/test/browser/less/nested-gradient-with-svg-gradient/*',
            'src/node_modules/less/test/browser/less/plugin/*',
            'src/node_modules/less/test/browser/less/postProcessor/*',
            'src/node_modules/less/test/browser/less/relative-urls/*',
            'src/node_modules/less/test/browser/less/rewrite-urls/*',
            'src/node_modules/less/test/browser/less/rootpath-relative/*',
            'src/node_modules/less/test/browser/less/rootpath-rewrite-urls/*',
            'src/node_modules/less/test/browser/less/rootpath/*',
            'src/node_modules/less/test/browser/vendor/*',
            'src/node_modules/less/test/css/*',
            'src/node_modules/less/test/css/3rd-party/*',
            'src/node_modules/less/test/css/compression/*',
            'src/node_modules/less/test/css/debug/*',
            'src/node_modules/less/test/css/filemanagerPlugin/*',
            'src/node_modules/less/test/css/globalVars/*',
            'src/node_modules/less/test/css/include-path-string/*',
            'src/node_modules/less/test/css/include-path/*',
            'src/node_modules/less/test/css/legacy/*',
            'src/node_modules/less/test/css/math/*',
            'src/node_modules/less/test/css/math/parens-division/*',
            'src/node_modules/less/test/css/math/strict-legacy/*',
            'src/node_modules/less/test/css/math/strict/*',
            'src/node_modules/less/test/css/modifyVars/*',
            'src/node_modules/less/test/css/namespacing/*',
            'src/node_modules/less/test/css/no-strict-math/*',
            'src/node_modules/less/test/css/postProcessorPlugin/*',
            'src/node_modules/less/test/css/preProcessorPlugin/*',
            'src/node_modules/less/test/css/rewrite-urls-all/*',
            'src/node_modules/less/test/css/rewrite-urls-local/*',
            'src/node_modules/less/test/css/rootpath-rewrite-urls-all/*',
            'src/node_modules/less/test/css/rootpath-rewrite-urls-local/*',
            'src/node_modules/less/test/css/static-urls/*',
            'src/node_modules/less/test/css/strict-units/*',
            'src/node_modules/less/test/css/url-args/*',
            'src/node_modules/less/test/css/visitorPlugin/*',
            'src/node_modules/less/test/data/*',
            'src/node_modules/less/test/import-module/*',
            'src/node_modules/less/test/import-module/one/*',
            'src/node_modules/less/test/import-module/one/two/*',
            'src/node_modules/less/test/import-module/one/two/three/*',
            'src/node_modules/less/test/less-bom/*',
            'src/node_modules/less/test/less-bom/3rd-party/*',
            'src/node_modules/less/test/less-bom/compression/*',
            'src/node_modules/less/test/less-bom/debug/*',
            'src/node_modules/less/test/less-bom/debug/import/*',
            'src/node_modules/less/test/less-bom/errors/*',
            'src/node_modules/less/test/less-bom/errors/imports/*',
            'src/node_modules/less/test/less-bom/errors/imports/subfolder/*',
            'src/node_modules/less/test/less-bom/errors/plugin/*',
            'src/node_modules/less/test/less-bom/filemanagerPlugin/*',
            'src/node_modules/less/test/less-bom/globalVars/*',
            'src/node_modules/less/test/less-bom/import-reference-issues/*',
            'src/node_modules/less/test/less-bom/import/*',
            'src/node_modules/less/test/less-bom/import/deeper/*',
            'src/node_modules/less/test/less-bom/import/deeper/deeper-2/*',
            'src/node_modules/less/test/less-bom/import/imports/*',
            'src/node_modules/less/test/less-bom/include-path-string/*',
            'src/node_modules/less/test/less-bom/include-path/*',
            'src/node_modules/less/test/less-bom/legacy/*',
            'src/node_modules/less/test/less-bom/math/*',
            'src/node_modules/less/test/less-bom/math/parens-division/*',
            'src/node_modules/less/test/less-bom/math/strict-legacy/*',
            'src/node_modules/less/test/less-bom/math/strict/*',
            'src/node_modules/less/test/less-bom/modifyVars/*',
            'src/node_modules/less/test/less-bom/namespacing/*',
            'src/node_modules/less/test/less-bom/namespacing/imports/*',
            'src/node_modules/less/test/less-bom/nested-gradient-with-svg-gradient/*',
            'src/node_modules/less/test/less-bom/no-js-errors/*',
            'src/node_modules/less/test/less-bom/no-strict-math/*',
            'src/node_modules/less/test/less-bom/plugin/*',
            'src/node_modules/less/test/less-bom/postProcessorPlugin/*',
            'src/node_modules/less/test/less-bom/preProcessorPlugin/*',
            'src/node_modules/less/test/less-bom/rewrite-urls-all/*',
            'src/node_modules/less/test/less-bom/rewrite-urls-all/folder/*',
            'src/node_modules/less/test/less-bom/rewrite-urls-local/*',
            'src/node_modules/less/test/less-bom/rewrite-urls-local/folder/*',
            'src/node_modules/less/test/less-bom/root-registry/*',
            'src/node_modules/less/test/less-bom/rootpath-rewrite-urls-all/*',
            'src/node_modules/less/test/less-bom/rootpath-rewrite-urls-all/folder/*',
            'src/node_modules/less/test/less-bom/rootpath-rewrite-urls-local/*',
            'src/node_modules/less/test/less-bom/rootpath-rewrite-urls-local/folder/*',
            'src/node_modules/less/test/less-bom/sourcemaps-empty/*',
            'src/node_modules/less/test/less-bom/sourcemaps/*',
            'src/node_modules/less/test/less-bom/static-urls/*',
            'src/node_modules/less/test/less-bom/strict-units/*',
            'src/node_modules/less/test/less-bom/url-args/*',
            'src/node_modules/less/test/less-bom/visitorPlugin/*',
            'src/node_modules/less/test/less/*',
            'src/node_modules/less/test/less/3rd-party/*',
            'src/node_modules/less/test/less/compression/*',
            'src/node_modules/less/test/less/debug/*',
            'src/node_modules/less/test/less/debug/import/*',
            'src/node_modules/less/test/less/errors/*',
            'src/node_modules/less/test/less/errors/imports/*',
            'src/node_modules/less/test/less/errors/imports/subfolder/*',
            'src/node_modules/less/test/less/errors/plugin/*',
            'src/node_modules/less/test/less/filemanagerPlugin/*',
            'src/node_modules/less/test/less/globalVars/*',
            'src/node_modules/less/test/less/import-reference-issues/*',
            'src/node_modules/less/test/less/import/*',
            'src/node_modules/less/test/less/import/deeper/*',
            'src/node_modules/less/test/less/import/deeper/deeper-2/*',
            'src/node_modules/less/test/less/import/imports/*',
            'src/node_modules/less/test/less/include-path-string/*',
            'src/node_modules/less/test/less/include-path/*',
            'src/node_modules/less/test/less/legacy/*',
            'src/node_modules/less/test/less/math/*',
            'src/node_modules/less/test/less/math/parens-division/*',
            'src/node_modules/less/test/less/math/strict-legacy/*',
            'src/node_modules/less/test/less/math/strict/*',
            'src/node_modules/less/test/less/modifyVars/*',
            'src/node_modules/less/test/less/namespacing/*',
            'src/node_modules/less/test/less/namespacing/imports/*',
            'src/node_modules/less/test/less/nested-gradient-with-svg-gradient/*',
            'src/node_modules/less/test/less/no-js-errors/*',
            'src/node_modules/less/test/less/no-strict-math/*',
            'src/node_modules/less/test/less/plugin/*',
            'src/node_modules/less/test/less/postProcessorPlugin/*',
            'src/node_modules/less/test/less/preProcessorPlugin/*',
            'src/node_modules/less/test/less/rewrite-urls-all/*',
            'src/node_modules/less/test/less/rewrite-urls-all/folder/*',
            'src/node_modules/less/test/less/rewrite-urls-local/*',
            'src/node_modules/less/test/less/rewrite-urls-local/folder/*',
            'src/node_modules/less/test/less/root-registry/*',
            'src/node_modules/less/test/less/rootpath-rewrite-urls-all/*',
            'src/node_modules/less/test/less/rootpath-rewrite-urls-all/folder/*',
            'src/node_modules/less/test/less/rootpath-rewrite-urls-local/*',
            'src/node_modules/less/test/less/rootpath-rewrite-urls-local/folder/*',
            'src/node_modules/less/test/less/sourcemaps-empty/*',
            'src/node_modules/less/test/less/sourcemaps/*',
            'src/node_modules/less/test/less/static-urls/*',
            'src/node_modules/less/test/less/strict-units/*',
            'src/node_modules/less/test/less/url-args/*',
            'src/node_modules/less/test/less/visitorPlugin/*',
            'src/node_modules/less/test/plugins/*',
            'src/node_modules/less/test/plugins/filemanager/*',
            'src/node_modules/less/test/plugins/postprocess/*',
            'src/node_modules/less/test/plugins/preprocess/*',
            'src/node_modules/less/test/plugins/visitor/*',
            'src/node_modules/less/test/sourcemaps/*',
            'src/node_modules/load-json-file/*',
            'src/node_modules/load-json-file/node_modules/*',
            'src/node_modules/load-json-file/node_modules/pify/*',
            'src/node_modules/loader-runner/*',
            'src/node_modules/loader-runner/lib/*',
            'src/node_modules/loader-utils/*',
            'src/node_modules/loader-utils/lib/*',
            'src/node_modules/loader-utils/node_modules/*',
            'src/node_modules/loader-utils/node_modules/.bin/*',
            'src/node_modules/locate-path/*',
            'src/node_modules/lodash._getnative/*',
            'src/node_modules/lodash.assign/*',
            'src/node_modules/lodash.camelcase/*',
            'src/node_modules/lodash.clonedeep/*',
            'src/node_modules/lodash.debounce/*',
            'src/node_modules/lodash.isarguments/*',
            'src/node_modules/lodash.isarray/*',
            'src/node_modules/lodash.keys/*',
            'src/node_modules/lodash.mergewith/*',
            'src/node_modules/lodash.tail/*',
            'src/node_modules/lodash.throttle/*',
            'src/node_modules/lodash/*',
            'src/node_modules/lodash/fp/*',
            'src/node_modules/loose-envify/*',
            'src/node_modules/loud-rejection/*',
            'src/node_modules/lru-cache/*',
            'src/node_modules/make-dir/*',
            'src/node_modules/map-age-cleaner/*',
            'src/node_modules/map-age-cleaner/dist/*',
            'src/node_modules/map-cache/*',
            'src/node_modules/map-obj/*',
            'src/node_modules/map-visit/*',
            'src/node_modules/md5.js/*',
            'src/node_modules/md5.js/node_modules/*',
            'src/node_modules/md5.js/node_modules/hash-base/*',
            'src/node_modules/mem/*',
            'src/node_modules/memory-fs/*',
            'src/node_modules/memory-fs/lib/*',
            'src/node_modules/memory-fs/node_modules/*',
            'src/node_modules/memory-fs/node_modules/.bin/*',
            'src/node_modules/meow/*',
            'src/node_modules/micromatch/*',
            'src/node_modules/micromatch/lib/*',
            'src/node_modules/micromatch/node_modules/*',
            'src/node_modules/micromatch/node_modules/define-property/*',
            'src/node_modules/micromatch/node_modules/extend-shallow/*',
            'src/node_modules/micromatch/node_modules/is-extendable/*',
            'src/node_modules/miller-rabin/*',
            'src/node_modules/miller-rabin/bin/*',
            'src/node_modules/miller-rabin/lib/*',
            'src/node_modules/miller-rabin/test/*',
            'src/node_modules/mime-db/*',
            'src/node_modules/mime-types/*',
            'src/node_modules/mime/*',
            'src/node_modules/mime/src/*',
            'src/node_modules/mimic-fn/*',
            'src/node_modules/mini-store/*',
            'src/node_modules/mini-store/lib/*',
            'src/node_modules/mini-store/node_modules/*',
            'src/node_modules/mini-store/node_modules/prop-types/*',
            'src/node_modules/mini-store/node_modules/prop-types/lib/*',
            'src/node_modules/mini-store/node_modules/prop-types/node_modules/*',
            'src/node_modules/mini-store/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/minimalistic-assert/*',
            'src/node_modules/minimalistic-crypto-utils/*',
            'src/node_modules/minimalistic-crypto-utils/lib/*',
            'src/node_modules/minimalistic-crypto-utils/test/*',
            'src/node_modules/minimatch/*',
            'src/node_modules/minimist/*',
            'src/node_modules/minimist/example/*',
            'src/node_modules/minimist/test/*',
            'src/node_modules/mississippi/*',
            'src/node_modules/mississippi/node_modules/*',
            'src/node_modules/mississippi/node_modules/pump/*',
            'src/node_modules/mixin-deep/*',
            'src/node_modules/mixin-deep/node_modules/*',
            'src/node_modules/mixin-deep/node_modules/is-extendable/*',
            'src/node_modules/mixin-object/*',
            'src/node_modules/mixin-object/node_modules/*',
            'src/node_modules/mixin-object/node_modules/for-in/*',
            'src/node_modules/mkdirp/*',
            'src/node_modules/mkdirp/bin/*',
            'src/node_modules/mkdirp/examples/*',
            'src/node_modules/mkdirp/node_modules/*',
            'src/node_modules/mkdirp/node_modules/minimist/*',
            'src/node_modules/mkdirp/node_modules/minimist/example/*',
            'src/node_modules/mkdirp/node_modules/minimist/test/*',
            'src/node_modules/mkdirp/test/*',
            'src/node_modules/moment/*',
            'src/node_modules/moment/locale/*',
            'src/node_modules/moment/min/*',
            'src/node_modules/moment/src/*',
            'src/node_modules/moment/src/lib/*',
            'src/node_modules/moment/src/lib/create/*',
            'src/node_modules/moment/src/lib/duration/*',
            'src/node_modules/moment/src/lib/format/*',
            'src/node_modules/moment/src/lib/locale/*',
            'src/node_modules/moment/src/lib/moment/*',
            'src/node_modules/moment/src/lib/parse/*',
            'src/node_modules/moment/src/lib/units/*',
            'src/node_modules/moment/src/lib/utils/*',
            'src/node_modules/moment/src/locale/*',
            'src/node_modules/move-concurrently/*',
            'src/node_modules/move-concurrently/node_modules/*',
            'src/node_modules/move-concurrently/node_modules/.bin/*',
            'src/node_modules/ms/*',
            'src/node_modules/msgpack-lite/*',
            'src/node_modules/msgpack-lite/bin/*',
            'src/node_modules/msgpack-lite/dist/*',
            'src/node_modules/msgpack-lite/lib/*',
            'src/node_modules/msgpack-lite/test/*',
            'src/node_modules/msgpack-lite/test/zuul/*',
            'src/node_modules/mutationobserver-shim/*',
            'src/node_modules/mutationobserver-shim/dist/*',
            'src/node_modules/nan/*',
            'src/node_modules/nan/doc/*',
            'src/node_modules/nan/tools/*',
            'src/node_modules/nanomatch/*',
            'src/node_modules/nanomatch/lib/*',
            'src/node_modules/nanomatch/node_modules/*',
            'src/node_modules/nanomatch/node_modules/define-property/*',
            'src/node_modules/nanomatch/node_modules/extend-shallow/*',
            'src/node_modules/nanomatch/node_modules/is-extendable/*',
            'src/node_modules/neo-async/*',
            'src/node_modules/nice-try/*',
            'src/node_modules/nice-try/src/*',
            'src/node_modules/node-fetch/*',
            'src/node_modules/node-fetch/lib/*',
            'src/node_modules/node-fetch/test/*',
            'src/node_modules/node-gyp/*',
            'src/node_modules/node-gyp/.github/*',
            'src/node_modules/node-gyp/bin/*',
            'src/node_modules/node-gyp/gyp/*',
            'src/node_modules/node-gyp/gyp/data/*',
            'src/node_modules/node-gyp/gyp/data/win/*',
            'src/node_modules/node-gyp/gyp/pylib/*',
            'src/node_modules/node-gyp/gyp/samples/*',
            'src/node_modules/node-gyp/gyp/tools/*',
            'src/node_modules/node-gyp/gyp/tools/Xcode/*',
            'src/node_modules/node-gyp/gyp/tools/Xcode/Specifications/*',
            'src/node_modules/node-gyp/gyp/tools/emacs/*',
            'src/node_modules/node-gyp/gyp/tools/emacs/testdata/*',
            'src/node_modules/node-gyp/lib/*',
            'src/node_modules/node-gyp/node_modules/*',
            'src/node_modules/node-gyp/node_modules/.bin/*',
            'src/node_modules/node-gyp/node_modules/ajv/*',
            'src/node_modules/node-gyp/node_modules/ajv/dist/*',
            'src/node_modules/node-gyp/node_modules/ajv/lib/*',
            'src/node_modules/node-gyp/node_modules/ajv/lib/compile/*',
            'src/node_modules/node-gyp/node_modules/ajv/lib/dot/*',
            'src/node_modules/node-gyp/node_modules/ajv/lib/dotjs/*',
            'src/node_modules/node-gyp/node_modules/ajv/lib/refs/*',
            'src/node_modules/node-gyp/node_modules/ajv/scripts/*',
            'src/node_modules/node-gyp/node_modules/aws4/*',
            'src/node_modules/node-gyp/node_modules/extend/*',
            'src/node_modules/node-gyp/node_modules/har-validator/*',
            'src/node_modules/node-gyp/node_modules/har-validator/lib/*',
            'src/node_modules/node-gyp/node_modules/mime-db/*',
            'src/node_modules/node-gyp/node_modules/mime-types/*',
            'src/node_modules/node-gyp/node_modules/oauth-sign/*',
            'src/node_modules/node-gyp/node_modules/qs/*',
            'src/node_modules/node-gyp/node_modules/qs/dist/*',
            'src/node_modules/node-gyp/node_modules/qs/lib/*',
            'src/node_modules/node-gyp/node_modules/qs/test/*',
            'src/node_modules/node-gyp/node_modules/request/*',
            'src/node_modules/node-gyp/node_modules/request/lib/*',
            'src/node_modules/node-gyp/node_modules/request/node_modules/*',
            'src/node_modules/node-gyp/node_modules/request/node_modules/.bin/*',
            'src/node_modules/node-gyp/node_modules/safe-buffer/*',
            'src/node_modules/node-gyp/node_modules/semver/*',
            'src/node_modules/node-gyp/node_modules/semver/bin/*',
            'src/node_modules/node-gyp/node_modules/tough-cookie/*',
            'src/node_modules/node-gyp/node_modules/tough-cookie/lib/*',
            'src/node_modules/node-gyp/node_modules/uuid/*',
            'src/node_modules/node-gyp/node_modules/uuid/bin/*',
            'src/node_modules/node-gyp/node_modules/uuid/lib/*',
            'src/node_modules/node-gyp/src/*',
            'src/node_modules/node-gyp/test/*',
            'src/node_modules/node-gyp/test/fixtures/*',
            'src/node_modules/node-gyp/tools/*',
            'src/node_modules/node-gyp/tools/gyp/*',
            'src/node_modules/node-gyp/tools/gyp/pylib/*',
            'src/node_modules/node-gyp/tools/gyp/pylib/gyp/*',
            'src/node_modules/node-gyp/tools/gyp/pylib/gyp/generator/*',
            'src/node_modules/node-libs-browser/*',
            'src/node_modules/node-libs-browser/mock/*',
            'src/node_modules/node-pre-gyp/*',
            'src/node_modules/node-pre-gyp/bin/*',
            'src/node_modules/node-pre-gyp/lib/*',
            'src/node_modules/node-pre-gyp/lib/util/*',
            'src/node_modules/node-pre-gyp/lib/util/nw-pre-gyp/*',
            'src/node_modules/node-pre-gyp/node_modules/*',
            'src/node_modules/node-pre-gyp/node_modules/.bin/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/dist/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/lib/compile/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/lib/dot/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/lib/dot/v5/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/lib/dotjs/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/lib/refs/*',
            'src/node_modules/node-pre-gyp/node_modules/ajv/scripts/*',
            'src/node_modules/node-pre-gyp/node_modules/assert-plus/*',
            'src/node_modules/node-pre-gyp/node_modules/aws-sign2/*',
            'src/node_modules/node-pre-gyp/node_modules/form-data/*',
            'src/node_modules/node-pre-gyp/node_modules/form-data/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/har-schema/*',
            'src/node_modules/node-pre-gyp/node_modules/har-schema/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/lib/browser/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/lib/node4/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/lib/node6/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/lib/node7/*',
            'src/node_modules/node-pre-gyp/node_modules/har-validator/src/*',
            'src/node_modules/node-pre-gyp/node_modules/http-signature/*',
            'src/node_modules/node-pre-gyp/node_modules/http-signature/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/http-signature/node_modules/*',
            'src/node_modules/node-pre-gyp/node_modules/http-signature/node_modules/.bin/*',
            'src/node_modules/node-pre-gyp/node_modules/nopt/*',
            'src/node_modules/node-pre-gyp/node_modules/nopt/bin/*',
            'src/node_modules/node-pre-gyp/node_modules/nopt/examples/*',
            'src/node_modules/node-pre-gyp/node_modules/nopt/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/nopt/test/*',
            'src/node_modules/node-pre-gyp/node_modules/performance-now/*',
            'src/node_modules/node-pre-gyp/node_modules/performance-now/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/performance-now/src/*',
            'src/node_modules/node-pre-gyp/node_modules/performance-now/test/*',
            'src/node_modules/node-pre-gyp/node_modules/qs/*',
            'src/node_modules/node-pre-gyp/node_modules/qs/dist/*',
            'src/node_modules/node-pre-gyp/node_modules/qs/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/qs/test/*',
            'src/node_modules/node-pre-gyp/node_modules/request/*',
            'src/node_modules/node-pre-gyp/node_modules/request/lib/*',
            'src/node_modules/node-pre-gyp/node_modules/request/node_modules/*',
            'src/node_modules/node-pre-gyp/node_modules/request/node_modules/.bin/*',
            'src/node_modules/node-releases/*',
            'src/node_modules/node-releases/.idea/*',
            'src/node_modules/node-releases/.idea/inspectionProfiles/*',
            'src/node_modules/node-releases/data/*',
            'src/node_modules/node-releases/data/processed/*',
            'src/node_modules/node-releases/data/raw/*',
            'src/node_modules/node-releases/data/release-schedule/*',
            'src/node_modules/node-releases/node_modules/*',
            'src/node_modules/node-releases/node_modules/.bin/*',
            'src/node_modules/node-sass/*',
            'src/node_modules/node-sass/bin/*',
            'src/node_modules/node-sass/lib/*',
            'src/node_modules/node-sass/node_modules/*',
            'src/node_modules/node-sass/node_modules/.bin/*',
            'src/node_modules/node-sass/node_modules/ansi-styles/*',
            'src/node_modules/node-sass/node_modules/chalk/*',
            'src/node_modules/node-sass/node_modules/cross-spawn/*',
            'src/node_modules/node-sass/node_modules/cross-spawn/lib/*',
            'src/node_modules/node-sass/node_modules/cross-spawn/node_modules/*',
            'src/node_modules/node-sass/node_modules/cross-spawn/node_modules/.bin/*',
            'src/node_modules/node-sass/node_modules/supports-color/*',
            'src/node_modules/node-sass/scripts/*',
            'src/node_modules/node-sass/scripts/util/*',
            'src/node_modules/node-sass/src/*',
            'src/node_modules/node-sass/src/libsass/*',
            'src/node_modules/node-sass/src/libsass/.github/*',
            'src/node_modules/node-sass/src/libsass/contrib/*',
            'src/node_modules/node-sass/src/libsass/docs/*',
            'src/node_modules/node-sass/src/libsass/include/*',
            'src/node_modules/node-sass/src/libsass/include/sass/*',
            'src/node_modules/node-sass/src/libsass/m4/*',
            'src/node_modules/node-sass/src/libsass/res/*',
            'src/node_modules/node-sass/src/libsass/script/*',
            'src/node_modules/node-sass/src/libsass/src/*',
            'src/node_modules/node-sass/src/libsass/src/b64/*',
            'src/node_modules/node-sass/src/libsass/src/memory/*',
            'src/node_modules/node-sass/src/libsass/src/support/*',
            'src/node_modules/node-sass/src/libsass/src/utf8/*',
            'src/node_modules/node-sass/src/libsass/test/*',
            'src/node_modules/node-sass/src/libsass/win/*',
            'src/node_modules/node-sass/src/sass_types/*',
            'src/node_modules/node-sass/test/*',
            'src/node_modules/node-sass/test/fixtures/*',
            'src/node_modules/node-sass/test/fixtures/compressed/*',
            'src/node_modules/node-sass/test/fixtures/custom-functions/*',
            'src/node_modules/node-sass/test/fixtures/cwd-include-path/*',
            'src/node_modules/node-sass/test/fixtures/cwd-include-path/root/*',
            'src/node_modules/node-sass/test/fixtures/depth-first/*',
            'src/node_modules/node-sass/test/fixtures/extras/*',
            'src/node_modules/node-sass/test/fixtures/follow/*',
            'src/node_modules/node-sass/test/fixtures/follow/foo/*',
            'src/node_modules/node-sass/test/fixtures/follow/foo/bar/*',
            'src/node_modules/node-sass/test/fixtures/include-files/*',
            'src/node_modules/node-sass/test/fixtures/include-path/*',
            'src/node_modules/node-sass/test/fixtures/include-path/functions/*',
            'src/node_modules/node-sass/test/fixtures/include-path/lib/*',
            'src/node_modules/node-sass/test/fixtures/indent/*',
            'src/node_modules/node-sass/test/fixtures/input-directory/*',
            'src/node_modules/node-sass/test/fixtures/input-directory/sass/*',
            'src/node_modules/node-sass/test/fixtures/input-directory/sass/nested/*',
            'src/node_modules/node-sass/test/fixtures/invalid/*',
            'src/node_modules/node-sass/test/fixtures/output-directory/*',
            'src/node_modules/node-sass/test/fixtures/precision/*',
            'src/node_modules/node-sass/test/fixtures/sass-path/*',
            'src/node_modules/node-sass/test/fixtures/sass-path/orange/*',
            'src/node_modules/node-sass/test/fixtures/sass-path/red/*',
            'src/node_modules/node-sass/test/fixtures/simple/*',
            'src/node_modules/node-sass/test/fixtures/source-comments/*',
            'src/node_modules/node-sass/test/fixtures/source-map-embed/*',
            'src/node_modules/node-sass/test/fixtures/source-map/*',
            'src/node_modules/node-sass/test/fixtures/watcher/*',
            'src/node_modules/node-sass/test/fixtures/watcher/main/*',
            'src/node_modules/node-sass/test/fixtures/watcher/main/partials/*',
            'src/node_modules/node-sass/test/fixtures/watcher/sibling/*',
            'src/node_modules/node-sass/test/fixtures/watcher/sibling/partials/*',
            'src/node_modules/node-sass/test/fixtures/watching-dir-01/*',
            'src/node_modules/node-sass/test/fixtures/watching-dir-02/*',
            'src/node_modules/node-sass/test/fixtures/watching/*',
            'src/node_modules/node-sass/test/scripts/*',
            'src/node_modules/node-sass/test/scripts/util/*',
            'src/node_modules/node-sass/vendor/*',
            'src/node_modules/node-sass/vendor/darwin-x64-64/*',
            'src/node_modules/nopt/*',
            'src/node_modules/nopt/bin/*',
            'src/node_modules/nopt/examples/*',
            'src/node_modules/nopt/lib/*',
            'src/node_modules/nopt/test/*',
            'src/node_modules/normalize-package-data/*',
            'src/node_modules/normalize-package-data/lib/*',
            'src/node_modules/normalize-package-data/node_modules/*',
            'src/node_modules/normalize-package-data/node_modules/.bin/*',
            'src/node_modules/normalize-path/*',
            'src/node_modules/normalize.css/*',
            'src/node_modules/npm-run-path/*',
            'src/node_modules/npmlog/*',
            'src/node_modules/number-is-nan/*',
            'src/node_modules/oauth-sign/*',
            'src/node_modules/object-assign/*',
            'src/node_modules/object-component/*',
            'src/node_modules/object-component/test/*',
            'src/node_modules/object-copy/*',
            'src/node_modules/object-copy/node_modules/*',
            'src/node_modules/object-copy/node_modules/kind-of/*',
            'src/node_modules/object-keys/*',
            'src/node_modules/object-keys/test/*',
            'src/node_modules/object-visit/*',
            'src/node_modules/object.getownpropertydescriptors/*',
            'src/node_modules/object.getownpropertydescriptors/test/*',
            'src/node_modules/object.pick/*',
            'src/node_modules/omit.js/*',
            'src/node_modules/omit.js/es/*',
            'src/node_modules/omit.js/lib/*',
            'src/node_modules/once/*',
            'src/node_modules/os-browserify/*',
            'src/node_modules/os-homedir/*',
            'src/node_modules/os-locale/*',
            'src/node_modules/os-tmpdir/*',
            'src/node_modules/osenv/*',
            'src/node_modules/p-defer/*',
            'src/node_modules/p-finally/*',
            'src/node_modules/p-is-promise/*',
            'src/node_modules/p-limit/*',
            'src/node_modules/p-locate/*',
            'src/node_modules/p-try/*',
            'src/node_modules/pako/*',
            'src/node_modules/pako/dist/*',
            'src/node_modules/pako/lib/*',
            'src/node_modules/pako/lib/utils/*',
            'src/node_modules/pako/lib/zlib/*',
            'src/node_modules/parallel-transform/*',
            'src/node_modules/parse-asn1/*',
            'src/node_modules/parse-asn1/test/*',
            'src/node_modules/parse-json/*',
            'src/node_modules/parse-json/vendor/*',
            'src/node_modules/parseqs/*',
            'src/node_modules/parseuri/*',
            'src/node_modules/pascalcase/*',
            'src/node_modules/path-browserify/*',
            'src/node_modules/path-dirname/*',
            'src/node_modules/path-exists/*',
            'src/node_modules/path-is-absolute/*',
            'src/node_modules/path-key/*',
            'src/node_modules/path-parse/*',
            'src/node_modules/path-to-regexp/*',
            'src/node_modules/path-to-regexp/node_modules/*',
            'src/node_modules/path-to-regexp/node_modules/isarray/*',
            'src/node_modules/path-to-regexp/node_modules/isarray/build/*',
            'src/node_modules/path-type/*',
            'src/node_modules/path-type/node_modules/*',
            'src/node_modules/path-type/node_modules/pify/*',
            'src/node_modules/pbkdf2/*',
            'src/node_modules/pbkdf2/lib/*',
            'src/node_modules/pbkdf2/node_modules/*',
            'src/node_modules/pbkdf2/node_modules/.bin/*',
            'src/node_modules/performance-now/*',
            'src/node_modules/performance-now/lib/*',
            'src/node_modules/performance-now/src/*',
            'src/node_modules/performance-now/test/*',
            'src/node_modules/performance-now/test/scripts/*',
            'src/node_modules/pify/*',
            'src/node_modules/pinkie-promise/*',
            'src/node_modules/pinkie/*',
            'src/node_modules/pkg-dir/*',
            'src/node_modules/posix-character-classes/*',
            'src/node_modules/postcss-modules-extract-imports/*',
            'src/node_modules/postcss-modules-extract-imports/lib/*',
            'src/node_modules/postcss-modules-local-by-default/*',
            'src/node_modules/postcss-modules-scope/*',
            'src/node_modules/postcss-modules-scope/lib/*',
            'src/node_modules/postcss-modules-values/*',
            'src/node_modules/postcss-modules-values/lib/*',
            'src/node_modules/postcss-modules-values/src/*',
            'src/node_modules/postcss-modules-values/test/*',
            'src/node_modules/postcss-value-parser/*',
            'src/node_modules/postcss-value-parser/lib/*',
            'src/node_modules/postcss/*',
            'src/node_modules/postcss/docs/*',
            'src/node_modules/postcss/docs/guidelines/*',
            'src/node_modules/postcss/lib/*',
            'src/node_modules/postcss/node_modules/*',
            'src/node_modules/postcss/node_modules/chalk/*',
            'src/node_modules/postcss/node_modules/chalk/types/*',
            'src/node_modules/private/*',
            'src/node_modules/process-nextick-args/*',
            'src/node_modules/process/*',
            'src/node_modules/promise-inflight/*',
            'src/node_modules/promise/*',
            'src/node_modules/promise/domains/*',
            'src/node_modules/promise/lib/*',
            'src/node_modules/promise/setimmediate/*',
            'src/node_modules/promise/src/*',
            'src/node_modules/prop-types/*',
            'src/node_modules/prop-types/lib/*',
            'src/node_modules/prop-types/node_modules/*',
            'src/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/prr/*',
            'src/node_modules/pseudomap/*',
            'src/node_modules/pseudomap/test/*',
            'src/node_modules/psl/*',
            'src/node_modules/psl/data/*',
            'src/node_modules/psl/dist/*',
            'src/node_modules/public-encrypt/*',
            'src/node_modules/public-encrypt/test/*',
            'src/node_modules/pump/*',
            'src/node_modules/pumpify/*',
            'src/node_modules/punycode/*',
            'src/node_modules/qs/*',
            'src/node_modules/qs/dist/*',
            'src/node_modules/qs/lib/*',
            'src/node_modules/qs/test/*',
            'src/node_modules/querystring-es3/*',
            'src/node_modules/querystring-es3/test/*',
            'src/node_modules/querystring/*',
            'src/node_modules/querystring/test/*',
            'src/node_modules/raf/*',
            'src/node_modules/randombytes/*',
            'src/node_modules/randomfill/*',
            'src/node_modules/rc-align/*',
            'src/node_modules/rc-align/es/*',
            'src/node_modules/rc-align/lib/*',
            'src/node_modules/rc-align/node_modules/*',
            'src/node_modules/rc-align/node_modules/prop-types/*',
            'src/node_modules/rc-align/node_modules/prop-types/lib/*',
            'src/node_modules/rc-align/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-align/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-animate/*',
            'src/node_modules/rc-animate/es/*',
            'src/node_modules/rc-animate/lib/*',
            'src/node_modules/rc-animate/node_modules/*',
            'src/node_modules/rc-animate/node_modules/prop-types/*',
            'src/node_modules/rc-animate/node_modules/prop-types/lib/*',
            'src/node_modules/rc-animate/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-animate/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-calendar/*',
            'src/node_modules/rc-calendar/assets/*',
            'src/node_modules/rc-calendar/dist/*',
            'src/node_modules/rc-calendar/es/*',
            'src/node_modules/rc-calendar/es/calendar/*',
            'src/node_modules/rc-calendar/es/date/*',
            'src/node_modules/rc-calendar/es/decade/*',
            'src/node_modules/rc-calendar/es/full-calendar/*',
            'src/node_modules/rc-calendar/es/locale/*',
            'src/node_modules/rc-calendar/es/mixin/*',
            'src/node_modules/rc-calendar/es/month/*',
            'src/node_modules/rc-calendar/es/picker/*',
            'src/node_modules/rc-calendar/es/range-calendar/*',
            'src/node_modules/rc-calendar/es/util/*',
            'src/node_modules/rc-calendar/es/year/*',
            'src/node_modules/rc-calendar/lib/*',
            'src/node_modules/rc-calendar/lib/calendar/*',
            'src/node_modules/rc-calendar/lib/date/*',
            'src/node_modules/rc-calendar/lib/decade/*',
            'src/node_modules/rc-calendar/lib/full-calendar/*',
            'src/node_modules/rc-calendar/lib/locale/*',
            'src/node_modules/rc-calendar/lib/mixin/*',
            'src/node_modules/rc-calendar/lib/month/*',
            'src/node_modules/rc-calendar/lib/picker/*',
            'src/node_modules/rc-calendar/lib/range-calendar/*',
            'src/node_modules/rc-calendar/lib/util/*',
            'src/node_modules/rc-calendar/lib/year/*',
            'src/node_modules/rc-calendar/node_modules/*',
            'src/node_modules/rc-calendar/node_modules/classnames/*',
            'src/node_modules/rc-calendar/node_modules/prop-types/*',
            'src/node_modules/rc-calendar/node_modules/prop-types/lib/*',
            'src/node_modules/rc-calendar/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-calendar/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-cascader/*',
            'src/node_modules/rc-cascader/assets/*',
            'src/node_modules/rc-cascader/es/*',
            'src/node_modules/rc-cascader/lib/*',
            'src/node_modules/rc-cascader/node_modules/*',
            'src/node_modules/rc-cascader/node_modules/array-tree-filter/*',
            'src/node_modules/rc-cascader/node_modules/array-tree-filter/test/*',
            'src/node_modules/rc-cascader/node_modules/prop-types/*',
            'src/node_modules/rc-cascader/node_modules/prop-types/lib/*',
            'src/node_modules/rc-cascader/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-cascader/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-cascader/node_modules/warning/*',
            'src/node_modules/rc-cascader/node_modules/warning/node_modules/*',
            'src/node_modules/rc-cascader/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/rc-checkbox/*',
            'src/node_modules/rc-checkbox/assets/*',
            'src/node_modules/rc-checkbox/es/*',
            'src/node_modules/rc-checkbox/lib/*',
            'src/node_modules/rc-checkbox/node_modules/*',
            'src/node_modules/rc-checkbox/node_modules/classnames/*',
            'src/node_modules/rc-checkbox/node_modules/prop-types/*',
            'src/node_modules/rc-checkbox/node_modules/prop-types/lib/*',
            'src/node_modules/rc-checkbox/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-checkbox/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-collapse/*',
            'src/node_modules/rc-collapse/assets/*',
            'src/node_modules/rc-collapse/es/*',
            'src/node_modules/rc-collapse/lib/*',
            'src/node_modules/rc-collapse/node_modules/*',
            'src/node_modules/rc-collapse/node_modules/classnames/*',
            'src/node_modules/rc-collapse/node_modules/prop-types/*',
            'src/node_modules/rc-collapse/node_modules/prop-types/lib/*',
            'src/node_modules/rc-collapse/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-collapse/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-dialog/*',
            'src/node_modules/rc-dialog/assets/*',
            'src/node_modules/rc-dialog/dist/*',
            'src/node_modules/rc-dialog/es/*',
            'src/node_modules/rc-dialog/lib/*',
            'src/node_modules/rc-drawer/*',
            'src/node_modules/rc-drawer/assets/*',
            'src/node_modules/rc-drawer/dist/*',
            'src/node_modules/rc-drawer/es/*',
            'src/node_modules/rc-drawer/lib/*',
            'src/node_modules/rc-drawer/node_modules/*',
            'src/node_modules/rc-drawer/node_modules/classnames/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/es/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/es/Children/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/es/Dom/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/es/debug/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/lib/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/lib/Children/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/lib/Dom/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/lib/debug/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/node_modules/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/node_modules/prop-types/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/node_modules/prop-types/lib/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-drawer/node_modules/rc-util/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-drawer/node_modules/shallowequal/*',
            'src/node_modules/rc-drawer/node_modules/shallowequal/modules/*',
            'src/node_modules/rc-dropdown/*',
            'src/node_modules/rc-dropdown/assets/*',
            'src/node_modules/rc-dropdown/es/*',
            'src/node_modules/rc-dropdown/lib/*',
            'src/node_modules/rc-dropdown/node_modules/*',
            'src/node_modules/rc-dropdown/node_modules/prop-types/*',
            'src/node_modules/rc-dropdown/node_modules/prop-types/lib/*',
            'src/node_modules/rc-dropdown/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-dropdown/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-dropdown/node_modules/rc-trigger/*',
            'src/node_modules/rc-dropdown/node_modules/rc-trigger/assets/*',
            'src/node_modules/rc-dropdown/node_modules/rc-trigger/es/*',
            'src/node_modules/rc-dropdown/node_modules/rc-trigger/lib/*',
            'src/node_modules/rc-dropdown/node_modules/react-lifecycles-compat/*',
            'src/node_modules/rc-editor-core/*',
            'src/node_modules/rc-editor-core/assets/*',
            'src/node_modules/rc-editor-core/es/*',
            'src/node_modules/rc-editor-core/es/EditorCore/*',
            'src/node_modules/rc-editor-core/es/EditorCore/export/*',
            'src/node_modules/rc-editor-core/es/Toolbar/*',
            'src/node_modules/rc-editor-core/lib/*',
            'src/node_modules/rc-editor-core/lib/EditorCore/*',
            'src/node_modules/rc-editor-core/lib/EditorCore/export/*',
            'src/node_modules/rc-editor-core/lib/Toolbar/*',
            'src/node_modules/rc-editor-core/node_modules/*',
            'src/node_modules/rc-editor-core/node_modules/classnames/*',
            'src/node_modules/rc-editor-core/node_modules/lodash/*',
            'src/node_modules/rc-editor-core/node_modules/lodash/fp/*',
            'src/node_modules/rc-editor-core/node_modules/prop-types/*',
            'src/node_modules/rc-editor-core/node_modules/prop-types/lib/*',
            'src/node_modules/rc-editor-core/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-editor-core/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-editor-core/type-definitions/*',
            'src/node_modules/rc-editor-mention/*',
            'src/node_modules/rc-editor-mention/assets/*',
            'src/node_modules/rc-editor-mention/es/*',
            'src/node_modules/rc-editor-mention/es/component/*',
            'src/node_modules/rc-editor-mention/es/component/__mocks__/*',
            'src/node_modules/rc-editor-mention/es/model/*',
            'src/node_modules/rc-editor-mention/es/utils/*',
            'src/node_modules/rc-editor-mention/lib/*',
            'src/node_modules/rc-editor-mention/lib/component/*',
            'src/node_modules/rc-editor-mention/lib/component/__mocks__/*',
            'src/node_modules/rc-editor-mention/lib/model/*',
            'src/node_modules/rc-editor-mention/lib/utils/*',
            'src/node_modules/rc-editor-mention/node_modules/*',
            'src/node_modules/rc-editor-mention/node_modules/classnames/*',
            'src/node_modules/rc-editor-mention/node_modules/prop-types/*',
            'src/node_modules/rc-editor-mention/node_modules/prop-types/lib/*',
            'src/node_modules/rc-editor-mention/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-editor-mention/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-hammerjs/*',
            'src/node_modules/rc-hammerjs/es/*',
            'src/node_modules/rc-hammerjs/lib/*',
            'src/node_modules/rc-hammerjs/node_modules/*',
            'src/node_modules/rc-hammerjs/node_modules/prop-types/*',
            'src/node_modules/rc-hammerjs/node_modules/prop-types/lib/*',
            'src/node_modules/rc-hammerjs/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-hammerjs/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-input-number/*',
            'src/node_modules/rc-input-number/assets/*',
            'src/node_modules/rc-input-number/dist/*',
            'src/node_modules/rc-input-number/es/*',
            'src/node_modules/rc-input-number/lib/*',
            'src/node_modules/rc-input-number/node_modules/*',
            'src/node_modules/rc-input-number/node_modules/classnames/*',
            'src/node_modules/rc-input-number/node_modules/prop-types/*',
            'src/node_modules/rc-input-number/node_modules/prop-types/lib/*',
            'src/node_modules/rc-input-number/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-input-number/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/es/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/es/Children/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/es/Dom/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/es/debug/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/lib/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/lib/Children/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/lib/Dom/*',
            'src/node_modules/rc-input-number/node_modules/rc-util/lib/debug/*',
            'src/node_modules/rc-input-number/node_modules/shallowequal/*',
            'src/node_modules/rc-input-number/node_modules/shallowequal/modules/*',
            'src/node_modules/rc-menu/*',
            'src/node_modules/rc-menu/assets/*',
            'src/node_modules/rc-menu/es/*',
            'src/node_modules/rc-menu/lib/*',
            'src/node_modules/rc-menu/node_modules/*',
            'src/node_modules/rc-menu/node_modules/classnames/*',
            'src/node_modules/rc-menu/node_modules/mini-store/*',
            'src/node_modules/rc-menu/node_modules/mini-store/lib/*',
            'src/node_modules/rc-menu/node_modules/prop-types/*',
            'src/node_modules/rc-menu/node_modules/prop-types/lib/*',
            'src/node_modules/rc-menu/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-menu/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-notification/*',
            'src/node_modules/rc-notification/assets/*',
            'src/node_modules/rc-notification/dist/*',
            'src/node_modules/rc-notification/es/*',
            'src/node_modules/rc-notification/lib/*',
            'src/node_modules/rc-notification/node_modules/*',
            'src/node_modules/rc-notification/node_modules/classnames/*',
            'src/node_modules/rc-notification/node_modules/prop-types/*',
            'src/node_modules/rc-notification/node_modules/prop-types/lib/*',
            'src/node_modules/rc-notification/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-notification/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-pagination/*',
            'src/node_modules/rc-pagination/assets/*',
            'src/node_modules/rc-pagination/dist/*',
            'src/node_modules/rc-pagination/es/*',
            'src/node_modules/rc-pagination/es/locale/*',
            'src/node_modules/rc-pagination/lib/*',
            'src/node_modules/rc-pagination/lib/locale/*',
            'src/node_modules/rc-pagination/node_modules/*',
            'src/node_modules/rc-pagination/node_modules/prop-types/*',
            'src/node_modules/rc-pagination/node_modules/prop-types/lib/*',
            'src/node_modules/rc-pagination/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-pagination/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-progress/*',
            'src/node_modules/rc-progress/assets/*',
            'src/node_modules/rc-progress/dist/*',
            'src/node_modules/rc-progress/es/*',
            'src/node_modules/rc-progress/lib/*',
            'src/node_modules/rc-progress/node_modules/*',
            'src/node_modules/rc-progress/node_modules/prop-types/*',
            'src/node_modules/rc-progress/node_modules/prop-types/lib/*',
            'src/node_modules/rc-progress/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-progress/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-rate/*',
            'src/node_modules/rc-rate/assets/*',
            'src/node_modules/rc-rate/es/*',
            'src/node_modules/rc-rate/lib/*',
            'src/node_modules/rc-rate/node_modules/*',
            'src/node_modules/rc-rate/node_modules/classnames/*',
            'src/node_modules/rc-rate/node_modules/prop-types/*',
            'src/node_modules/rc-rate/node_modules/prop-types/lib/*',
            'src/node_modules/rc-rate/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-rate/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-select/*',
            'src/node_modules/rc-select/assets/*',
            'src/node_modules/rc-select/es/*',
            'src/node_modules/rc-select/lib/*',
            'src/node_modules/rc-select/node_modules/*',
            'src/node_modules/rc-select/node_modules/classnames/*',
            'src/node_modules/rc-select/node_modules/prop-types/*',
            'src/node_modules/rc-select/node_modules/prop-types/lib/*',
            'src/node_modules/rc-select/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-select/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-select/node_modules/rc-trigger/*',
            'src/node_modules/rc-select/node_modules/rc-trigger/assets/*',
            'src/node_modules/rc-select/node_modules/rc-trigger/es/*',
            'src/node_modules/rc-select/node_modules/rc-trigger/lib/*',
            'src/node_modules/rc-select/node_modules/rc-trigger/node_modules/*',
            'src/node_modules/rc-select/node_modules/rc-trigger/node_modules/classnames/*',
            'src/node_modules/rc-select/node_modules/react-lifecycles-compat/*',
            'src/node_modules/rc-select/node_modules/warning/*',
            'src/node_modules/rc-select/node_modules/warning/node_modules/*',
            'src/node_modules/rc-select/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/rc-slider/*',
            'src/node_modules/rc-slider/assets/*',
            'src/node_modules/rc-slider/dist/*',
            'src/node_modules/rc-slider/es/*',
            'src/node_modules/rc-slider/es/common/*',
            'src/node_modules/rc-slider/lib/*',
            'src/node_modules/rc-slider/lib/common/*',
            'src/node_modules/rc-slider/node_modules/*',
            'src/node_modules/rc-slider/node_modules/classnames/*',
            'src/node_modules/rc-slider/node_modules/prop-types/*',
            'src/node_modules/rc-slider/node_modules/prop-types/lib/*',
            'src/node_modules/rc-slider/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-slider/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-steps/*',
            'src/node_modules/rc-steps/assets/*',
            'src/node_modules/rc-steps/es/*',
            'src/node_modules/rc-steps/lib/*',
            'src/node_modules/rc-steps/node_modules/*',
            'src/node_modules/rc-steps/node_modules/classnames/*',
            'src/node_modules/rc-steps/node_modules/lodash/*',
            'src/node_modules/rc-steps/node_modules/lodash/fp/*',
            'src/node_modules/rc-steps/node_modules/prop-types/*',
            'src/node_modules/rc-steps/node_modules/prop-types/lib/*',
            'src/node_modules/rc-steps/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-steps/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-switch/*',
            'src/node_modules/rc-switch/assets/*',
            'src/node_modules/rc-switch/es/*',
            'src/node_modules/rc-switch/lib/*',
            'src/node_modules/rc-switch/node_modules/*',
            'src/node_modules/rc-switch/node_modules/classnames/*',
            'src/node_modules/rc-switch/node_modules/prop-types/*',
            'src/node_modules/rc-switch/node_modules/prop-types/lib/*',
            'src/node_modules/rc-switch/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-switch/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-table/*',
            'src/node_modules/rc-table/assets/*',
            'src/node_modules/rc-table/dist/*',
            'src/node_modules/rc-table/es/*',
            'src/node_modules/rc-table/lib/*',
            'src/node_modules/rc-table/node_modules/*',
            'src/node_modules/rc-table/node_modules/classnames/*',
            'src/node_modules/rc-table/node_modules/lodash/*',
            'src/node_modules/rc-table/node_modules/lodash/fp/*',
            'src/node_modules/rc-table/node_modules/prop-types/*',
            'src/node_modules/rc-table/node_modules/prop-types/lib/*',
            'src/node_modules/rc-table/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-table/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-table/node_modules/react-lifecycles-compat/*',
            'src/node_modules/rc-tabs/*',
            'src/node_modules/rc-tabs/assets/*',
            'src/node_modules/rc-tabs/dist/*',
            'src/node_modules/rc-tabs/es/*',
            'src/node_modules/rc-tabs/lib/*',
            'src/node_modules/rc-tabs/node_modules/*',
            'src/node_modules/rc-tabs/node_modules/classnames/*',
            'src/node_modules/rc-tabs/node_modules/lodash/*',
            'src/node_modules/rc-tabs/node_modules/lodash/fp/*',
            'src/node_modules/rc-tabs/node_modules/prop-types/*',
            'src/node_modules/rc-tabs/node_modules/prop-types/lib/*',
            'src/node_modules/rc-tabs/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-tabs/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-time-picker/*',
            'src/node_modules/rc-time-picker/assets/*',
            'src/node_modules/rc-time-picker/es/*',
            'src/node_modules/rc-time-picker/lib/*',
            'src/node_modules/rc-time-picker/node_modules/*',
            'src/node_modules/rc-time-picker/node_modules/classnames/*',
            'src/node_modules/rc-time-picker/node_modules/prop-types/*',
            'src/node_modules/rc-time-picker/node_modules/prop-types/lib/*',
            'src/node_modules/rc-time-picker/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-time-picker/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-tooltip/*',
            'src/node_modules/rc-tooltip/assets/*',
            'src/node_modules/rc-tooltip/dist/*',
            'src/node_modules/rc-tooltip/es/*',
            'src/node_modules/rc-tooltip/lib/*',
            'src/node_modules/rc-tooltip/node_modules/*',
            'src/node_modules/rc-tooltip/node_modules/prop-types/*',
            'src/node_modules/rc-tooltip/node_modules/prop-types/lib/*',
            'src/node_modules/rc-tooltip/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-tooltip/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-tree-select/*',
            'src/node_modules/rc-tree-select/assets/*',
            'src/node_modules/rc-tree-select/dist/*',
            'src/node_modules/rc-tree-select/es/*',
            'src/node_modules/rc-tree-select/es/Base/*',
            'src/node_modules/rc-tree-select/es/Popup/*',
            'src/node_modules/rc-tree-select/es/Selector/*',
            'src/node_modules/rc-tree-select/es/Selector/MultipleSelector/*',
            'src/node_modules/rc-tree-select/lib/*',
            'src/node_modules/rc-tree-select/lib/Base/*',
            'src/node_modules/rc-tree-select/lib/Popup/*',
            'src/node_modules/rc-tree-select/lib/Selector/*',
            'src/node_modules/rc-tree-select/lib/Selector/MultipleSelector/*',
            'src/node_modules/rc-tree-select/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/classnames/*',
            'src/node_modules/rc-tree-select/node_modules/prop-types/*',
            'src/node_modules/rc-tree-select/node_modules/prop-types/lib/*',
            'src/node_modules/rc-tree-select/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-tree-select/node_modules/rc-animate/*',
            'src/node_modules/rc-tree-select/node_modules/rc-animate/es/*',
            'src/node_modules/rc-tree-select/node_modules/rc-animate/lib/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/assets/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/dist/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/es/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/lib/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/es/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/es/Children/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/es/Dom/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/es/debug/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/lib/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/lib/Children/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/lib/Dom/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/rc-util/lib/debug/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/shallowequal/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/shallowequal/modules/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/warning/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/warning/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/rc-tree/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/assets/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/es/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/lib/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/classnames/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/rc-animate/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/rc-animate/es/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/rc-animate/lib/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/rc-animate/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/rc-trigger/node_modules/rc-animate/node_modules/classnames/*',
            'src/node_modules/rc-tree-select/node_modules/warning/*',
            'src/node_modules/rc-tree-select/node_modules/warning/node_modules/*',
            'src/node_modules/rc-tree-select/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/rc-tree/*',
            'src/node_modules/rc-tree/assets/*',
            'src/node_modules/rc-tree/dist/*',
            'src/node_modules/rc-tree/es/*',
            'src/node_modules/rc-tree/lib/*',
            'src/node_modules/rc-tree/node_modules/*',
            'src/node_modules/rc-tree/node_modules/classnames/*',
            'src/node_modules/rc-tree/node_modules/prop-types/*',
            'src/node_modules/rc-tree/node_modules/prop-types/lib/*',
            'src/node_modules/rc-tree/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-tree/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/es/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/lib/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/es/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/es/Children/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/es/Dom/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/es/debug/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/lib/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/lib/Children/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/lib/Dom/*',
            'src/node_modules/rc-tree/node_modules/rc-animate/node_modules/rc-util/lib/debug/*',
            'src/node_modules/rc-tree/node_modules/rc-util/*',
            'src/node_modules/rc-tree/node_modules/rc-util/es/*',
            'src/node_modules/rc-tree/node_modules/rc-util/es/Children/*',
            'src/node_modules/rc-tree/node_modules/rc-util/es/Dom/*',
            'src/node_modules/rc-tree/node_modules/rc-util/es/debug/*',
            'src/node_modules/rc-tree/node_modules/rc-util/lib/*',
            'src/node_modules/rc-tree/node_modules/rc-util/lib/Children/*',
            'src/node_modules/rc-tree/node_modules/rc-util/lib/Dom/*',
            'src/node_modules/rc-tree/node_modules/rc-util/lib/debug/*',
            'src/node_modules/rc-tree/node_modules/shallowequal/*',
            'src/node_modules/rc-tree/node_modules/shallowequal/modules/*',
            'src/node_modules/rc-trigger/*',
            'src/node_modules/rc-trigger/assets/*',
            'src/node_modules/rc-trigger/es/*',
            'src/node_modules/rc-trigger/lib/*',
            'src/node_modules/rc-trigger/node_modules/*',
            'src/node_modules/rc-trigger/node_modules/dom-align/*',
            'src/node_modules/rc-trigger/node_modules/dom-align/es/*',
            'src/node_modules/rc-trigger/node_modules/dom-align/lib/*',
            'src/node_modules/rc-trigger/node_modules/prop-types/*',
            'src/node_modules/rc-trigger/node_modules/prop-types/lib/*',
            'src/node_modules/rc-trigger/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-trigger/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-trigger/node_modules/rc-align/*',
            'src/node_modules/rc-trigger/node_modules/rc-align/es/*',
            'src/node_modules/rc-trigger/node_modules/rc-align/lib/*',
            'src/node_modules/rc-upload/*',
            'src/node_modules/rc-upload/es/*',
            'src/node_modules/rc-upload/lib/*',
            'src/node_modules/rc-upload/node_modules/*',
            'src/node_modules/rc-upload/node_modules/classnames/*',
            'src/node_modules/rc-upload/node_modules/prop-types/*',
            'src/node_modules/rc-upload/node_modules/prop-types/lib/*',
            'src/node_modules/rc-upload/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-upload/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-upload/node_modules/warning/*',
            'src/node_modules/rc-upload/node_modules/warning/node_modules/*',
            'src/node_modules/rc-upload/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/rc-util/*',
            'src/node_modules/rc-util/es/*',
            'src/node_modules/rc-util/es/Children/*',
            'src/node_modules/rc-util/es/Dom/*',
            'src/node_modules/rc-util/es/debug/*',
            'src/node_modules/rc-util/lib/*',
            'src/node_modules/rc-util/lib/Children/*',
            'src/node_modules/rc-util/lib/Dom/*',
            'src/node_modules/rc-util/lib/debug/*',
            'src/node_modules/rc-util/node_modules/*',
            'src/node_modules/rc-util/node_modules/prop-types/*',
            'src/node_modules/rc-util/node_modules/prop-types/lib/*',
            'src/node_modules/rc-util/node_modules/prop-types/node_modules/*',
            'src/node_modules/rc-util/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/rc-util/node_modules/shallowequal/*',
            'src/node_modules/rc-util/node_modules/shallowequal/modules/*',
            'src/node_modules/rc/*',
            'src/node_modules/rc/lib/*',
            'src/node_modules/rc/test/*',
            'src/node_modules/react-dom/*',
            'src/node_modules/react-dom/cjs/*',
            'src/node_modules/react-dom/node_modules/*',
            'src/node_modules/react-dom/node_modules/.bin/*',
            'src/node_modules/react-dom/umd/*',
            'src/node_modules/react-lazy-load/*',
            'src/node_modules/react-lazy-load/dist/*',
            'src/node_modules/react-lazy-load/lib/*',
            'src/node_modules/react-lazy-load/lib/utils/*',
            'src/node_modules/react-lazy-load/lib/utils/__mocks__/*',
            'src/node_modules/react-lazy-load/node_modules/*',
            'src/node_modules/react-lazy-load/node_modules/prop-types/*',
            'src/node_modules/react-lazy-load/node_modules/prop-types/lib/*',
            'src/node_modules/react-lazy-load/node_modules/prop-types/node_modules/*',
            'src/node_modules/react-lazy-load/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/react-lifecycles-compat/*',
            'src/node_modules/react-router-dom/*',
            'src/node_modules/react-router-dom/es/*',
            'src/node_modules/react-router-dom/node_modules/*',
            'src/node_modules/react-router-dom/node_modules/.bin/*',
            'src/node_modules/react-router-dom/node_modules/prop-types/*',
            'src/node_modules/react-router-dom/node_modules/prop-types/lib/*',
            'src/node_modules/react-router-dom/node_modules/prop-types/node_modules/*',
            'src/node_modules/react-router-dom/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/react-router-dom/node_modules/warning/*',
            'src/node_modules/react-router-dom/node_modules/warning/node_modules/*',
            'src/node_modules/react-router-dom/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/react-router-dom/umd/*',
            'src/node_modules/react-router/*',
            'src/node_modules/react-router/es/*',
            'src/node_modules/react-router/node_modules/*',
            'src/node_modules/react-router/node_modules/.bin/*',
            'src/node_modules/react-router/node_modules/hoist-non-react-statics/*',
            'src/node_modules/react-router/node_modules/hoist-non-react-statics/dist/*',
            'src/node_modules/react-router/node_modules/hoist-non-react-statics/src/*',
            'src/node_modules/react-router/node_modules/prop-types/*',
            'src/node_modules/react-router/node_modules/prop-types/lib/*',
            'src/node_modules/react-router/node_modules/prop-types/node_modules/*',
            'src/node_modules/react-router/node_modules/prop-types/node_modules/.bin/*',
            'src/node_modules/react-router/node_modules/warning/*',
            'src/node_modules/react-router/node_modules/warning/node_modules/*',
            'src/node_modules/react-router/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/react-router/umd/*',
            'src/node_modules/react-slick/*',
            'src/node_modules/react-slick/dist/*',
            'src/node_modules/react-slick/lib/*',
            'src/node_modules/react-slick/lib/mixins/*',
            'src/node_modules/react-slick/lib/utils/*',
            'src/node_modules/react-slick/node_modules/*',
            'src/node_modules/react-slick/node_modules/classnames/*',
            'src/node_modules/react/*',
            'src/node_modules/react/cjs/*',
            'src/node_modules/react/node_modules/*',
            'src/node_modules/react/node_modules/.bin/*',
            'src/node_modules/react/umd/*',
            'src/node_modules/read-pkg-up/*',
            'src/node_modules/read-pkg-up/node_modules/*',
            'src/node_modules/read-pkg-up/node_modules/find-up/*',
            'src/node_modules/read-pkg-up/node_modules/path-exists/*',
            'src/node_modules/read-pkg/*',
            'src/node_modules/readable-stream/*',
            'src/node_modules/readable-stream/doc/*',
            'src/node_modules/readable-stream/doc/wg-meetings/*',
            'src/node_modules/readable-stream/lib/*',
            'src/node_modules/readable-stream/lib/internal/*',
            'src/node_modules/readable-stream/lib/internal/streams/*',
            'src/node_modules/readdirp/*',
            'src/node_modules/readdirp/examples/*',
            'src/node_modules/readdirp/test/*',
            'src/node_modules/readdirp/test/bed/*',
            'src/node_modules/readdirp/test/bed/root_dir1/*',
            'src/node_modules/readdirp/test/bed/root_dir1/root_dir1_subdir1/*',
            'src/node_modules/readdirp/test/bed/root_dir2/*',
            'src/node_modules/redent/*',
            'src/node_modules/redent/node_modules/*',
            'src/node_modules/redent/node_modules/.bin/*',
            'src/node_modules/regenerate-unicode-properties/*',
            'src/node_modules/regenerate-unicode-properties/Binary_Property/*',
            'src/node_modules/regenerate-unicode-properties/General_Category/*',
            'src/node_modules/regenerate-unicode-properties/Script/*',
            'src/node_modules/regenerate-unicode-properties/Script_Extensions/*',
            'src/node_modules/regenerate/*',
            'src/node_modules/regenerator-runtime/*',
            'src/node_modules/regenerator-transform/*',
            'src/node_modules/regenerator-transform/lib/*',
            'src/node_modules/regenerator-transform/src/*',
            'src/node_modules/regex-not/*',
            'src/node_modules/regex-not/node_modules/*',
            'src/node_modules/regex-not/node_modules/extend-shallow/*',
            'src/node_modules/regex-not/node_modules/is-extendable/*',
            'src/node_modules/regexpu-core/*',
            'src/node_modules/regexpu-core/data/*',
            'src/node_modules/regexpu-core/node_modules/*',
            'src/node_modules/regexpu-core/node_modules/.bin/*',
            'src/node_modules/regjsgen/*',
            'src/node_modules/regjsparser/*',
            'src/node_modules/regjsparser/bin/*',
            'src/node_modules/regjsparser/node_modules/*',
            'src/node_modules/regjsparser/node_modules/.bin/*',
            'src/node_modules/remove-trailing-separator/*',
            'src/node_modules/repeat-element/*',
            'src/node_modules/repeat-string/*',
            'src/node_modules/repeating/*',
            'src/node_modules/request/*',
            'src/node_modules/request/lib/*',
            'src/node_modules/request/node_modules/*',
            'src/node_modules/request/node_modules/.bin/*',
            'src/node_modules/require-directory/*',
            'src/node_modules/require-main-filename/*',
            'src/node_modules/resize-observer-polyfill/*',
            'src/node_modules/resize-observer-polyfill/dist/*',
            'src/node_modules/resize-observer-polyfill/src/*',
            'src/node_modules/resize-observer-polyfill/src/shims/*',
            'src/node_modules/resize-observer-polyfill/src/utils/*',
            'src/node_modules/resolve-cwd/*',
            'src/node_modules/resolve-from/*',
            'src/node_modules/resolve-pathname/*',
            'src/node_modules/resolve-pathname/cjs/*',
            'src/node_modules/resolve-pathname/umd/*',
            'src/node_modules/resolve-url/*',
            'src/node_modules/resolve-url/test/*',
            'src/node_modules/resolve/*',
            'src/node_modules/resolve/example/*',
            'src/node_modules/resolve/lib/*',
            'src/node_modules/resolve/test/*',
            'src/node_modules/resolve/test/dotdot/*',
            'src/node_modules/resolve/test/dotdot/abc/*',
            'src/node_modules/resolve/test/module_dir/*',
            'src/node_modules/resolve/test/module_dir/xmodules/*',
            'src/node_modules/resolve/test/module_dir/xmodules/aaa/*',
            'src/node_modules/resolve/test/module_dir/ymodules/*',
            'src/node_modules/resolve/test/module_dir/ymodules/aaa/*',
            'src/node_modules/resolve/test/module_dir/zmodules/*',
            'src/node_modules/resolve/test/module_dir/zmodules/bbb/*',
            'src/node_modules/resolve/test/node_path/*',
            'src/node_modules/resolve/test/node_path/x/*',
            'src/node_modules/resolve/test/node_path/x/aaa/*',
            'src/node_modules/resolve/test/node_path/x/ccc/*',
            'src/node_modules/resolve/test/node_path/y/*',
            'src/node_modules/resolve/test/node_path/y/bbb/*',
            'src/node_modules/resolve/test/node_path/y/ccc/*',
            'src/node_modules/resolve/test/pathfilter/*',
            'src/node_modules/resolve/test/pathfilter/deep_ref/*',
            'src/node_modules/resolve/test/precedence/*',
            'src/node_modules/resolve/test/precedence/aaa/*',
            'src/node_modules/resolve/test/precedence/bbb/*',
            'src/node_modules/resolve/test/resolver/*',
            'src/node_modules/resolve/test/resolver/baz/*',
            'src/node_modules/resolve/test/resolver/browser_field/*',
            'src/node_modules/resolve/test/resolver/dot_main/*',
            'src/node_modules/resolve/test/resolver/dot_slash_main/*',
            'src/node_modules/resolve/test/resolver/incorrect_main/*',
            'src/node_modules/resolve/test/resolver/other_path/*',
            'src/node_modules/resolve/test/resolver/other_path/lib/*',
            'src/node_modules/resolve/test/resolver/quux/*',
            'src/node_modules/resolve/test/resolver/quux/foo/*',
            'src/node_modules/resolve/test/resolver/same_names/*',
            'src/node_modules/resolve/test/resolver/same_names/foo/*',
            'src/node_modules/resolve/test/resolver/symlinked/*',
            'src/node_modules/resolve/test/resolver/symlinked/_/*',
            'src/node_modules/resolve/test/resolver/symlinked/_/node_modules/*',
            'src/node_modules/resolve/test/resolver/symlinked/_/symlink_target/*',
            'src/node_modules/resolve/test/resolver/without_basedir/*',
            'src/node_modules/ret/*',
            'src/node_modules/ret/lib/*',
            'src/node_modules/rimraf/*',
            'src/node_modules/ripemd160/*',
            'src/node_modules/rmc-feedback/*',
            'src/node_modules/rmc-feedback/dist/*',
            'src/node_modules/rmc-feedback/es/*',
            'src/node_modules/rmc-feedback/lib/*',
            'src/node_modules/rmc-feedback/node_modules/*',
            'src/node_modules/rmc-feedback/node_modules/classnames/*',
            'src/node_modules/run-queue/*',
            'src/node_modules/safe-buffer/*',
            'src/node_modules/safe-regex/*',
            'src/node_modules/safe-regex/example/*',
            'src/node_modules/safe-regex/test/*',
            'src/node_modules/safer-buffer/*',
            'src/node_modules/sass-graph/*',
            'src/node_modules/sass-graph/bin/*',
            'src/node_modules/sass-graph/node_modules/*',
            'src/node_modules/sass-graph/node_modules/cliui/*',
            'src/node_modules/sass-graph/node_modules/invert-kv/*',
            'src/node_modules/sass-graph/node_modules/lcid/*',
            'src/node_modules/sass-graph/node_modules/lodash/*',
            'src/node_modules/sass-graph/node_modules/lodash/fp/*',
            'src/node_modules/sass-graph/node_modules/os-locale/*',
            'src/node_modules/sass-graph/node_modules/which-module/*',
            'src/node_modules/sass-graph/node_modules/y18n/*',
            'src/node_modules/sass-graph/node_modules/yargs-parser/*',
            'src/node_modules/sass-graph/node_modules/yargs-parser/lib/*',
            'src/node_modules/sass-graph/node_modules/yargs/*',
            'src/node_modules/sass-graph/node_modules/yargs/lib/*',
            'src/node_modules/sass-graph/node_modules/yargs/locales/*',
            'src/node_modules/sass-loader/*',
            'src/node_modules/sass-loader/lib/*',
            'src/node_modules/sass-loader/node_modules/*',
            'src/node_modules/sass-loader/node_modules/.bin/*',
            'src/node_modules/schedule/*',
            'src/node_modules/schedule/cjs/*',
            'src/node_modules/schedule/umd/*',
            'src/node_modules/schema-utils/*',
            'src/node_modules/schema-utils/dist/*',
            'src/node_modules/schema-utils/node_modules/*',
            'src/node_modules/schema-utils/node_modules/.bin/*',
            'src/node_modules/scss-tokenizer/*',
            'src/node_modules/scss-tokenizer/lib/*',
            'src/node_modules/scss-tokenizer/node_modules/*',
            'src/node_modules/scss-tokenizer/node_modules/source-map/*',
            'src/node_modules/scss-tokenizer/node_modules/source-map/build/*',
            'src/node_modules/scss-tokenizer/node_modules/source-map/lib/*',
            'src/node_modules/scss-tokenizer/node_modules/source-map/lib/source-map/*',
            'src/node_modules/semver/*',
            'src/node_modules/semver/bin/*',
            'src/node_modules/serialize-javascript/*',
            'src/node_modules/set-blocking/*',
            'src/node_modules/set-immediate-shim/*',
            'src/node_modules/set-value/*',
            'src/node_modules/setimmediate/*',
            'src/node_modules/sha.js/*',
            'src/node_modules/sha.js/test/*',
            'src/node_modules/shallow-clone/*',
            'src/node_modules/shallow-clone/node_modules/*',
            'src/node_modules/shallow-clone/node_modules/kind-of/*',
            'src/node_modules/shallow-equal/*',
            'src/node_modules/shallow-equal/arrays/*',
            'src/node_modules/shallow-equal/objects/*',
            'src/node_modules/shallowequal/*',
            'src/node_modules/shebang-command/*',
            'src/node_modules/shebang-regex/*',
            'src/node_modules/signal-exit/*',
            'src/node_modules/snapdragon-node/*',
            'src/node_modules/snapdragon-node/node_modules/*',
            'src/node_modules/snapdragon-node/node_modules/define-property/*',
            'src/node_modules/snapdragon-util/*',
            'src/node_modules/snapdragon-util/node_modules/*',
            'src/node_modules/snapdragon-util/node_modules/kind-of/*',
            'src/node_modules/snapdragon/*',
            'src/node_modules/snapdragon/lib/*',
            'src/node_modules/snapdragon/node_modules/*',
            'src/node_modules/snapdragon/node_modules/debug/*',
            'src/node_modules/snapdragon/node_modules/debug/src/*',
            'src/node_modules/snapdragon/node_modules/source-map/*',
            'src/node_modules/snapdragon/node_modules/source-map/dist/*',
            'src/node_modules/snapdragon/node_modules/source-map/lib/*',
            'src/node_modules/sntp/*',
            'src/node_modules/sntp/examples/*',
            'src/node_modules/sntp/lib/*',
            'src/node_modules/sntp/node_modules/*',
            'src/node_modules/sntp/node_modules/hoek/*',
            'src/node_modules/sntp/node_modules/hoek/images/*',
            'src/node_modules/sntp/node_modules/hoek/lib/*',
            'src/node_modules/sntp/node_modules/hoek/test/*',
            'src/node_modules/sntp/node_modules/hoek/test/modules/*',
            'src/node_modules/sntp/test/*',
            'src/node_modules/socket.io-client/*',
            'src/node_modules/socket.io-client/dist/*',
            'src/node_modules/socket.io-client/lib/*',
            'src/node_modules/socket.io-parser/*',
            'src/node_modules/socket.io-parser/node_modules/*',
            'src/node_modules/socket.io-parser/node_modules/isarray/*',
            'src/node_modules/source-list-map/*',
            'src/node_modules/source-list-map/lib/*',
            'src/node_modules/source-map-resolve/*',
            'src/node_modules/source-map-resolve/lib/*',
            'src/node_modules/source-map-resolve/node_modules/*',
            'src/node_modules/source-map-resolve/node_modules/.bin/*',
            'src/node_modules/source-map-url/*',
            'src/node_modules/source-map-url/test/*',
            'src/node_modules/source-map/*',
            'src/node_modules/source-map/dist/*',
            'src/node_modules/source-map/lib/*',
            'src/node_modules/spdx-correct/*',
            'src/node_modules/spdx-exceptions/*',
            'src/node_modules/spdx-expression-parse/*',
            'src/node_modules/spdx-license-ids/*',
            'src/node_modules/split-string/*',
            'src/node_modules/split-string/node_modules/*',
            'src/node_modules/split-string/node_modules/extend-shallow/*',
            'src/node_modules/split-string/node_modules/is-extendable/*',
            'src/node_modules/sshpk/*',
            'src/node_modules/sshpk/bin/*',
            'src/node_modules/sshpk/lib/*',
            'src/node_modules/sshpk/lib/formats/*',
            'src/node_modules/sshpk/man/*',
            'src/node_modules/sshpk/man/man1/*',
            'src/node_modules/ssri/*',
            'src/node_modules/static-extend/*',
            'src/node_modules/stdout-stream/*',
            'src/node_modules/stdout-stream/test/*',
            'src/node_modules/stdout-stream/test/fixtures/*',
            'src/node_modules/stream-browserify/*',
            'src/node_modules/stream-browserify/test/*',
            'src/node_modules/stream-each/*',
            'src/node_modules/stream-http/*',
            'src/node_modules/stream-http/lib/*',
            'src/node_modules/stream-http/test/*',
            'src/node_modules/stream-http/test/browser/*',
            'src/node_modules/stream-http/test/browser/lib/*',
            'src/node_modules/stream-http/test/node/*',
            'src/node_modules/stream-http/test/server/*',
            'src/node_modules/stream-http/test/server/static/*',
            'src/node_modules/stream-shift/*',
            'src/node_modules/string-convert/*',
            'src/node_modules/string-convert/test/*',
            'src/node_modules/string-width/*',
            'src/node_modules/string_decoder/*',
            'src/node_modules/string_decoder/lib/*',
            'src/node_modules/stringstream/*',
            'src/node_modules/strip-ansi/*',
            'src/node_modules/strip-bom/*',
            'src/node_modules/strip-eof/*',
            'src/node_modules/strip-indent/*',
            'src/node_modules/strip-json-comments/*',
            'src/node_modules/style-loader/*',
            'src/node_modules/style-loader/lib/*',
            'src/node_modules/supports-color/*',
            'src/node_modules/tapable/*',
            'src/node_modules/tapable/lib/*',
            'src/node_modules/tapable/lib/__tests__/*',
            'src/node_modules/tapable/lib/__tests__/__snapshots__/*',
            'src/node_modules/tar-pack/*',
            'src/node_modules/tar-pack/node_modules/*',
            'src/node_modules/tar-pack/node_modules/.bin/*',
            'src/node_modules/tar-pack/node_modules/debug/*',
            'src/node_modules/tar-pack/node_modules/debug/src/*',
            'src/node_modules/tar-pack/test/*',
            'src/node_modules/tar-pack/test/fixtures/*',
            'src/node_modules/tar-pack/test/fixtures/to-pack/*',
            'src/node_modules/tar/*',
            'src/node_modules/tar/examples/*',
            'src/node_modules/tar/lib/*',
            'src/node_modules/tar/test/*',
            'src/node_modules/through2/*',
            'src/node_modules/timers-browserify/*',
            'src/node_modules/tinycolor2/*',
            'src/node_modules/tinycolor2/demo/*',
            'src/node_modules/tinycolor2/dist/*',
            'src/node_modules/tinycolor2/docs/*',
            'src/node_modules/tinycolor2/test/*',
            'src/node_modules/to-array/*',
            'src/node_modules/to-arraybuffer/*',
            'src/node_modules/to-fast-properties/*',
            'src/node_modules/to-object-path/*',
            'src/node_modules/to-object-path/node_modules/*',
            'src/node_modules/to-object-path/node_modules/kind-of/*',
            'src/node_modules/to-regex-range/*',
            'src/node_modules/to-regex/*',
            'src/node_modules/to-regex/node_modules/*',
            'src/node_modules/to-regex/node_modules/define-property/*',
            'src/node_modules/to-regex/node_modules/extend-shallow/*',
            'src/node_modules/to-regex/node_modules/is-extendable/*',
            'src/node_modules/tough-cookie/*',
            'src/node_modules/tough-cookie/lib/*',
            'src/node_modules/trim-newlines/*',
            'src/node_modules/trim-right/*',
            'src/node_modules/true-case-path/*',
            'src/node_modules/true-case-path/node_modules/*',
            'src/node_modules/true-case-path/node_modules/glob/*',
            'src/node_modules/tslib/*',
            'src/node_modules/tslib/docs/*',
            'src/node_modules/tty-browserify/*',
            'src/node_modules/tunnel-agent/*',
            'src/node_modules/tweetnacl/*',
            'src/node_modules/typedarray/*',
            'src/node_modules/typedarray/example/*',
            'src/node_modules/typedarray/test/*',
            'src/node_modules/typedarray/test/server/*',
            'src/node_modules/ua-parser-js/*',
            'src/node_modules/ua-parser-js/dist/*',
            'src/node_modules/ua-parser-js/src/*',
            'src/node_modules/ua-parser-js/test/*',
            'src/node_modules/uglify-es/*',
            'src/node_modules/uglify-es/bin/*',
            'src/node_modules/uglify-es/lib/*',
            'src/node_modules/uglify-es/tools/*',
            'src/node_modules/uglifyjs-webpack-plugin/*',
            'src/node_modules/uglifyjs-webpack-plugin/dist/*',
            'src/node_modules/uglifyjs-webpack-plugin/dist/uglify/*',
            'src/node_modules/uglifyjs-webpack-plugin/dist/utils/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/.bin/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/lib/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/lib/content/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/lib/util/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/locales/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/node_modules/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/cacache/node_modules/.bin/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/mississippi/*',
            'src/node_modules/uglifyjs-webpack-plugin/node_modules/ssri/*',
            'src/node_modules/uid-number/*',
            'src/node_modules/ultron/*',
            'src/node_modules/unicode-canonical-property-names-ecmascript/*',
            'src/node_modules/unicode-match-property-ecmascript/*',
            'src/node_modules/unicode-match-property-value-ecmascript/*',
            'src/node_modules/unicode-match-property-value-ecmascript/data/*',
            'src/node_modules/unicode-property-aliases-ecmascript/*',
            'src/node_modules/union-value/*',
            'src/node_modules/union-value/node_modules/*',
            'src/node_modules/union-value/node_modules/set-value/*',
            'src/node_modules/unique-filename/*',
            'src/node_modules/unique-filename/.nyc_output/*',
            'src/node_modules/unique-filename/coverage/*',
            'src/node_modules/unique-filename/coverage/__root__/*',
            'src/node_modules/unique-filename/test/*',
            'src/node_modules/unique-slug/*',
            'src/node_modules/unique-slug/test/*',
            'src/node_modules/unset-value/*',
            'src/node_modules/unset-value/node_modules/*',
            'src/node_modules/unset-value/node_modules/has-value/*',
            'src/node_modules/unset-value/node_modules/has-value/node_modules/*',
            'src/node_modules/unset-value/node_modules/has-value/node_modules/isobject/*',
            'src/node_modules/unset-value/node_modules/has-values/*',
            'src/node_modules/upath/*',
            'src/node_modules/upath/build/*',
            'src/node_modules/upath/build/code/*',
            'src/node_modules/uri-js/*',
            'src/node_modules/uri-js/dist/*',
            'src/node_modules/uri-js/dist/es5/*',
            'src/node_modules/uri-js/dist/esnext/*',
            'src/node_modules/uri-js/dist/esnext/schemes/*',
            'src/node_modules/uri-js/node_modules/*',
            'src/node_modules/uri-js/node_modules/punycode/*',
            'src/node_modules/uri-js/src/*',
            'src/node_modules/uri-js/src/schemes/*',
            'src/node_modules/uri-js/tests/*',
            'src/node_modules/urix/*',
            'src/node_modules/urix/test/*',
            'src/node_modules/url/*',
            'src/node_modules/url/node_modules/*',
            'src/node_modules/url/node_modules/punycode/*',
            'src/node_modules/use/*',
            'src/node_modules/util-deprecate/*',
            'src/node_modules/util.promisify/*',
            'src/node_modules/util/*',
            'src/node_modules/util/node_modules/*',
            'src/node_modules/util/node_modules/inherits/*',
            'src/node_modules/util/support/*',
            'src/node_modules/util/test/*',
            'src/node_modules/util/test/browser/*',
            'src/node_modules/util/test/node/*',
            'src/node_modules/uuid/*',
            'src/node_modules/uuid/bin/*',
            'src/node_modules/uuid/lib/*',
            'src/node_modules/v8-compile-cache/*',
            'src/node_modules/validate-npm-package-license/*',
            'src/node_modules/value-equal/*',
            'src/node_modules/value-equal/cjs/*',
            'src/node_modules/value-equal/umd/*',
            'src/node_modules/verror/*',
            'src/node_modules/verror/lib/*',
            'src/node_modules/verror/node_modules/*',
            'src/node_modules/verror/node_modules/extsprintf/*',
            'src/node_modules/verror/node_modules/extsprintf/lib/*',
            'src/node_modules/verror/node_modules/extsprintf/test/*',
            'src/node_modules/vm-browserify/*',
            'src/node_modules/vm-browserify/example/*',
            'src/node_modules/vm-browserify/example/run/*',
            'src/node_modules/vm-browserify/test/*',
            'src/node_modules/warning/*',
            'src/node_modules/warning/node_modules/*',
            'src/node_modules/warning/node_modules/.bin/*',
            'src/node_modules/watchpack/*',
            'src/node_modules/watchpack/lib/*',
            'src/node_modules/webpack-cli/*',
            'src/node_modules/webpack-cli/bin/*',
            'src/node_modules/webpack-cli/node_modules/*',
            'src/node_modules/webpack-cli/node_modules/.bin/*',
            'src/node_modules/webpack-cli/node_modules/supports-color/*',
            'src/node_modules/webpack-merge/*',
            'src/node_modules/webpack-merge/lib/*',
            'src/node_modules/webpack-merge/node_modules/*',
            'src/node_modules/webpack-merge/node_modules/lodash/*',
            'src/node_modules/webpack-merge/node_modules/lodash/fp/*',
            'src/node_modules/webpack-sources/*',
            'src/node_modules/webpack-sources/lib/*',
            'src/node_modules/webpack/*',
            'src/node_modules/webpack/bin/*',
            'src/node_modules/webpack/buildin/*',
            'src/node_modules/webpack/hot/*',
            'src/node_modules/webpack/lib/*',
            'src/node_modules/webpack/lib/debug/*',
            'src/node_modules/webpack/lib/dependencies/*',
            'src/node_modules/webpack/lib/node/*',
            'src/node_modules/webpack/lib/optimize/*',
            'src/node_modules/webpack/lib/performance/*',
            'src/node_modules/webpack/lib/util/*',
            'src/node_modules/webpack/lib/wasm/*',
            'src/node_modules/webpack/lib/web/*',
            'src/node_modules/webpack/lib/webworker/*',
            'src/node_modules/webpack/node_modules/*',
            'src/node_modules/webpack/node_modules/.bin/*',
            'src/node_modules/webpack/node_modules/webpack-sources/*',
            'src/node_modules/webpack/node_modules/webpack-sources/lib/*',
            'src/node_modules/webpack/schemas/*',
            'src/node_modules/webpack/schemas/plugins/*',
            'src/node_modules/webpack/schemas/plugins/debug/*',
            'src/node_modules/webpack/schemas/plugins/optimize/*',
            'src/node_modules/webpack/web_modules/*',
            'src/node_modules/whatwg-fetch/*',
            'src/node_modules/which-module/*',
            'src/node_modules/which/*',
            'src/node_modules/which/bin/*',
            'src/node_modules/wide-align/*',
            'src/node_modules/worker-farm/*',
            'src/node_modules/worker-farm/examples/*',
            'src/node_modules/worker-farm/examples/basic/*',
            'src/node_modules/worker-farm/examples/pi/*',
            'src/node_modules/worker-farm/lib/*',
            'src/node_modules/worker-farm/lib/child/*',
            'src/node_modules/worker-farm/node_modules/*',
            'src/node_modules/worker-farm/node_modules/.bin/*',
            'src/node_modules/worker-farm/tests/*',
            'src/node_modules/wrap-ansi/*',
            'src/node_modules/wrappy/*',
            'src/node_modules/ws/*',
            'src/node_modules/ws/lib/*',
            'src/node_modules/xmlhttprequest-ssl/*',
            'src/node_modules/xmlhttprequest-ssl/example/*',
            'src/node_modules/xmlhttprequest-ssl/lib/*',
            'src/node_modules/xmlhttprequest-ssl/tests/*',
            'src/node_modules/xregexp/*',
            'src/node_modules/xregexp/lib/*',
            'src/node_modules/xregexp/lib/addons/*',
            'src/node_modules/xregexp/src/*',
            'src/node_modules/xregexp/src/addons/*',
            'src/node_modules/xtend/*',
            'src/node_modules/y18n/*',
            'src/node_modules/yallist/*',
            'src/node_modules/yargs-parser/*',
            'src/node_modules/yargs-parser/lib/*',
            'src/node_modules/yargs-parser/node_modules/*',
            'src/node_modules/yargs-parser/node_modules/camelcase/*',
            'src/node_modules/yargs/*',
            'src/node_modules/yargs/lib/*',
            'src/node_modules/yargs/locales/*',
            'src/node_modules/yargs/node_modules/*',
            'src/node_modules/yargs/node_modules/ansi-regex/*',
            'src/node_modules/yargs/node_modules/decamelize/*',
            'src/node_modules/yargs/node_modules/is-fullwidth-code-point/*',
            'src/node_modules/yargs/node_modules/string-width/*',
            'src/node_modules/yargs/node_modules/strip-ansi/*',
            'src/node_modules/yeast/*',
            'templates/*']}

install_requires = \
['click',
 'eventlet',
 'flask',
 'flask-socketio',
 'jinja2',
 'markdown',
 'msgpack']

setup(name='bowtie',
      version='0.10.0',
      description='Interactive Dashboard Toolkit.',
      author='Jacques Kvam',
      author_email='jwkvam+pypi@gmail.com',
      url='https://github.com/jwkvam/bowtie',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.6',
     )
